@@ -1,10 +1,11 @@
 <?php
 /**
- * @author Joas Schilling <nickvergessen@owncloud.com>
+ * @author Joas Schilling <coding@schilljs.com>
  * @author Stefan Weil <sw@weilnetz.de>
+ * @author Thomas Citharel <tcit@tcit.fr>
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  *
- * @copyright Copyright (c) 2016, ownCloud, Inc.
+ * @copyright Copyright (c) 2017, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -23,11 +24,14 @@
 
 namespace OCA\DAV\CalDAV;
 
+use Doctrine\DBAL\Connection;
 use OCA\DAV\DAV\Sharing\IShareable;
 use OCP\DB\QueryBuilder\IQueryBuilder;
 use OCA\DAV\Connector\Sabre\Principal;
 use OCA\DAV\DAV\Sharing\Backend;
+use OCP\IConfig;
 use OCP\IDBConnection;
+use OCP\Security\ISecureRandom;
 use Sabre\CalDAV\Backend\AbstractBackend;
 use Sabre\CalDAV\Backend\SchedulingSupport;
 use Sabre\CalDAV\Backend\SubscriptionSupport;
@@ -37,6 +41,7 @@ use Sabre\CalDAV\Xml\Property\ScheduleCalendarTransp;
 use Sabre\CalDAV\Xml\Property\SupportedCalendarComponentSet;
 use Sabre\DAV;
 use Sabre\DAV\Exception\Forbidden;
+use Sabre\DAV\Exception\NotFound;
 use Sabre\DAV\PropPatch;
 use Sabre\HTTP\URLUtil;
 use Sabre\VObject\DateTimeParser;
@@ -62,6 +67,7 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 	 */
 	const MAX_DATE = '2038-01-01';
 
+	const ACCESS_PUBLIC = 4;
 	const CLASSIFICATION_PUBLIC = 0;
 	const CLASSIFICATION_PRIVATE = 1;
 	const CLASSIFICATION_CONFIDENTIAL = 2;
@@ -106,16 +112,32 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 	/** @var Principal */
 	private $principalBackend;
 
+	/** @var IConfig */
+	private $config;
+
+	/** @var ISecureRandom */
+	private $random;
+	/** @var bool */
+	private $legacyMode;
+
 	/**
 	 * CalDavBackend constructor.
 	 *
 	 * @param IDBConnection $db
 	 * @param Principal $principalBackend
+	 * @param IConfig $config
 	 */
-	public function __construct(IDBConnection $db, Principal $principalBackend) {
+	public function __construct(IDBConnection $db,
+								Principal $principalBackend,
+								IConfig $config,
+								ISecureRandom $random,
+								$legacyMode = false) {
 		$this->db = $db;
 		$this->principalBackend = $principalBackend;
 		$this->sharingBackend = new Backend($this->db, $principalBackend, 'calendar');
+		$this->config = $config;
+		$this->random = $random;
+		$this->legacyMode = $legacyMode;
 	}
 
 	/**
@@ -172,7 +194,7 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 			$calendar = [
 				'id' => $row['id'],
 				'uri' => $row['uri'],
-				'principaluri' => $this->convertPrincipal($row['principaluri'], false),
+				'principaluri' => $this->convertPrincipal($row['principaluri']),
 				'{' . Plugin::NS_CALENDARSERVER . '}getctag' => 'http://sabre.io/ns/sync/' . ($row['synctoken']?$row['synctoken']:'0'),
 				'{http://sabredav.org/ns}sync-token' => $row['synctoken']?$row['synctoken']:'0',
 				'{' . Plugin::NS_CALDAV . '}supported-calendar-component-set' => new SupportedCalendarComponentSet($components),
@@ -209,7 +231,7 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 			->where($query->expr()->in('s.principaluri', $query->createParameter('principaluri')))
 			->andWhere($query->expr()->eq('s.type', $query->createParameter('type')))
 			->setParameter('type', 'calendar')
-			->setParameter('principaluri', $principals, \Doctrine\DBAL\Connection::PARAM_STR_ARRAY)
+			->setParameter('principaluri', $principals, Connection::PARAM_STR_ARRAY)
 			->execute();
 
 		while($row = $result->fetch()) {
@@ -223,12 +245,12 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 			$calendar = [
 				'id' => $row['id'],
 				'uri' => $uri,
-				'principaluri' => $principalUri,
+				'principaluri' => $this->convertPrincipal($principalUri),
 				'{' . Plugin::NS_CALENDARSERVER . '}getctag' => 'http://sabre.io/ns/sync/' . ($row['synctoken']?$row['synctoken']:'0'),
 				'{http://sabredav.org/ns}sync-token' => $row['synctoken']?$row['synctoken']:'0',
 				'{' . Plugin::NS_CALDAV . '}supported-calendar-component-set' => new SupportedCalendarComponentSet($components),
 				'{' . Plugin::NS_CALDAV . '}schedule-calendar-transp' => new ScheduleCalendarTransp($row['transparent']?'transparent':'opaque'),
-				'{' . \OCA\DAV\DAV\Sharing\Plugin::NS_OWNCLOUD . '}owner-principal' => $row['principaluri'],
+				'{' . \OCA\DAV\DAV\Sharing\Plugin::NS_OWNCLOUD . '}owner-principal' => $this->convertPrincipal($row['principaluri']),
 				'{' . \OCA\DAV\DAV\Sharing\Plugin::NS_OWNCLOUD . '}read-only' => (int)$row['access'] === Backend::ACCESS_READ,
 			];
 
@@ -245,6 +267,169 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 		return array_values($calendars);
 	}
 
+	public function getUsersOwnCalendars($principalUri) {
+		$principalUri = $this->convertPrincipal($principalUri, true);
+		$fields = array_values($this->propertyMap);
+		$fields[] = 'id';
+		$fields[] = 'uri';
+		$fields[] = 'synctoken';
+		$fields[] = 'components';
+		$fields[] = 'principaluri';
+		$fields[] = 'transparent';
+
+		// Making fields a comma-delimited list
+		$query = $this->db->getQueryBuilder();
+		$query->select($fields)->from('calendars')
+			->where($query->expr()->eq('principaluri', $query->createNamedParameter($principalUri)))
+			->orderBy('calendarorder', 'ASC');
+		$stmt = $query->execute();
+
+		$calendars = [];
+		while($row = $stmt->fetch(\PDO::FETCH_ASSOC)) {
+
+			$components = [];
+			if ($row['components']) {
+				$components = explode(',',$row['components']);
+			}
+
+			$calendar = [
+				'id' => $row['id'],
+				'uri' => $row['uri'],
+				'principaluri' => $this->convertPrincipal($row['principaluri']),
+				'{' . Plugin::NS_CALENDARSERVER . '}getctag' => 'http://sabre.io/ns/sync/' . ($row['synctoken']?$row['synctoken']:'0'),
+				'{http://sabredav.org/ns}sync-token' => $row['synctoken']?$row['synctoken']:'0',
+				'{' . Plugin::NS_CALDAV . '}supported-calendar-component-set' => new SupportedCalendarComponentSet($components),
+				'{' . Plugin::NS_CALDAV . '}schedule-calendar-transp' => new ScheduleCalendarTransp($row['transparent']?'transparent':'opaque'),
+			];
+
+			foreach($this->propertyMap as $xmlName=>$dbName) {
+				$calendar[$xmlName] = $row[$dbName];
+			}
+
+			if (!isset($calendars[$calendar['id']])) {
+				$calendars[$calendar['id']] = $calendar;
+			}
+		}
+
+		$stmt->closeCursor();
+
+		return array_values($calendars);
+	}
+
+	/**
+	 * @return array
+	 */
+	public function getPublicCalendars() {
+		$fields = array_values($this->propertyMap);
+		$fields[] = 'a.id';
+		$fields[] = 'a.uri';
+		$fields[] = 'a.synctoken';
+		$fields[] = 'a.components';
+		$fields[] = 'a.principaluri';
+		$fields[] = 'a.transparent';
+		$fields[] = 's.access';
+		$fields[] = 's.publicuri';
+		$calendars = [];
+		$query = $this->db->getQueryBuilder();
+		$result = $query->select($fields)
+			->from('dav_shares', 's')
+			->join('s', 'calendars', 'a', $query->expr()->eq('s.resourceid', 'a.id'))
+			->where($query->expr()->in('s.access', $query->createNamedParameter(self::ACCESS_PUBLIC)))
+			->andWhere($query->expr()->eq('s.type', $query->createNamedParameter('calendar')))
+			->execute();
+
+		while($row = $result->fetch()) {
+			list(, $name) = URLUtil::splitPath($row['principaluri']);
+			$row['displayname'] = $row['displayname'] . "($name)";
+			$components = [];
+			if ($row['components']) {
+				$components = explode(',',$row['components']);
+			}
+			$calendar = [
+				'id' => $row['id'],
+				'uri' => $row['publicuri'],
+				'principaluri' => $this->convertPrincipal($row['principaluri']),
+				'{' . Plugin::NS_CALENDARSERVER . '}getctag' => 'http://sabre.io/ns/sync/' . ($row['synctoken']?$row['synctoken']:'0'),
+				'{http://sabredav.org/ns}sync-token' => $row['synctoken']?$row['synctoken']:'0',
+				'{' . Plugin::NS_CALDAV . '}supported-calendar-component-set' => new SupportedCalendarComponentSet($components),
+				'{' . Plugin::NS_CALDAV . '}schedule-calendar-transp' => new ScheduleCalendarTransp($row['transparent']?'transparent':'opaque'),
+				'{' . \OCA\DAV\DAV\Sharing\Plugin::NS_OWNCLOUD . '}owner-principal' => $this->convertPrincipal($row['principaluri']),
+				'{' . \OCA\DAV\DAV\Sharing\Plugin::NS_OWNCLOUD . '}read-only' => (int)$row['access'] === Backend::ACCESS_READ,
+				'{' . \OCA\DAV\DAV\Sharing\Plugin::NS_OWNCLOUD . '}public' => (int)$row['access'] === self::ACCESS_PUBLIC,
+			];
+
+			foreach($this->propertyMap as $xmlName=>$dbName) {
+				$calendar[$xmlName] = $row[$dbName];
+			}
+
+			if (!isset($calendars[$calendar['id']])) {
+				$calendars[$calendar['id']] = $calendar;
+			}
+		}
+		$result->closeCursor();
+
+		return array_values($calendars);
+	}
+
+	/**
+	 * @param string $uri
+	 * @return array
+	 * @throws NotFound
+	 */
+	public function getPublicCalendar($uri) {
+		$fields = array_values($this->propertyMap);
+		$fields[] = 'a.id';
+		$fields[] = 'a.uri';
+		$fields[] = 'a.synctoken';
+		$fields[] = 'a.components';
+		$fields[] = 'a.principaluri';
+		$fields[] = 'a.transparent';
+		$fields[] = 's.access';
+		$fields[] = 's.publicuri';
+		$query = $this->db->getQueryBuilder();
+		$result = $query->select($fields)
+			->from('dav_shares', 's')
+			->join('s', 'calendars', 'a', $query->expr()->eq('s.resourceid', 'a.id'))
+			->where($query->expr()->in('s.access', $query->createNamedParameter(self::ACCESS_PUBLIC)))
+			->andWhere($query->expr()->eq('s.type', $query->createNamedParameter('calendar')))
+			->andWhere($query->expr()->eq('s.publicuri', $query->createNamedParameter($uri)))
+			->execute();
+
+		$row = $result->fetch(\PDO::FETCH_ASSOC);
+
+		$result->closeCursor();
+
+		if ($row === false) {
+			throw new NotFound('Node with name \'' . $uri . '\' could not be found');
+		}
+
+		list(, $name) = URLUtil::splitPath($row['principaluri']);
+		$row['displayname'] = $row['displayname'] . ' ' . "($name)";
+		$components = [];
+		if ($row['components']) {
+			$components = explode(',',$row['components']);
+		}
+		$calendar = [
+			'id' => $row['id'],
+			'uri' => $row['publicuri'],
+			'principaluri' => $this->convertPrincipal($row['principaluri']),
+			'{' . Plugin::NS_CALENDARSERVER . '}getctag' => 'http://sabre.io/ns/sync/' . ($row['synctoken']?$row['synctoken']:'0'),
+			'{http://sabredav.org/ns}sync-token' => $row['synctoken']?$row['synctoken']:'0',
+			'{' . Plugin::NS_CALDAV . '}supported-calendar-component-set' => new SupportedCalendarComponentSet($components),
+			'{' . Plugin::NS_CALDAV . '}schedule-calendar-transp' => new ScheduleCalendarTransp($row['transparent']?'transparent':'opaque'),
+			'{' . \OCA\DAV\DAV\Sharing\Plugin::NS_OWNCLOUD . '}owner-principal' => $this->convertPrincipal($row['principaluri']),
+			'{' . \OCA\DAV\DAV\Sharing\Plugin::NS_OWNCLOUD . '}read-only' => (int)$row['access'] === Backend::ACCESS_READ,
+			'{' . \OCA\DAV\DAV\Sharing\Plugin::NS_OWNCLOUD . '}public' => (int)$row['access'] === self::ACCESS_PUBLIC,
+		];
+
+		foreach($this->propertyMap as $xmlName=>$dbName) {
+			$calendar[$xmlName] = $row[$dbName];
+		}
+
+		return $calendar;
+
+	}
+
 	/**
 	 * @param string $principal
 	 * @param string $uri
@@ -281,7 +466,7 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 		$calendar = [
 			'id' => $row['id'],
 			'uri' => $row['uri'],
-			'principaluri' => $row['principaluri'],
+			'principaluri' => $this->convertPrincipal($row['principaluri']),
 			'{' . Plugin::NS_CALENDARSERVER . '}getctag' => 'http://sabre.io/ns/sync/' . ($row['synctoken']?$row['synctoken']:'0'),
 			'{http://sabredav.org/ns}sync-token' => $row['synctoken']?$row['synctoken']:'0',
 			'{' . Plugin::NS_CALDAV . '}supported-calendar-component-set' => new SupportedCalendarComponentSet($components),
@@ -325,7 +510,7 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 		$calendar = [
 			'id' => $row['id'],
 			'uri' => $row['uri'],
-			'principaluri' => $row['principaluri'],
+			'principaluri' => $this->convertPrincipal($row['principaluri']),
 			'{' . Plugin::NS_CALENDARSERVER . '}getctag' => 'http://sabre.io/ns/sync/' . ($row['synctoken']?$row['synctoken']:'0'),
 			'{http://sabredav.org/ns}sync-token' => $row['synctoken']?$row['synctoken']:'0',
 			'{' . Plugin::NS_CALDAV . '}supported-calendar-component-set' => new SupportedCalendarComponentSet($components),
@@ -349,8 +534,10 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 	 * @param string $calendarUri
 	 * @param array $properties
 	 * @return int
+	 * @throws DAV\Exception
 	 */
 	function createCalendar($principalUri, $calendarUri, array $properties) {
+		$principalUri = $this->convertPrincipal($principalUri, true);
 		$values = [
 			'principaluri' => $principalUri,
 			'uri'          => $calendarUri,
@@ -400,6 +587,7 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 	 *
 	 * Read the PropPatch documentation for more info and examples.
 	 *
+	 * @param mixed $calendarId
 	 * @param PropPatch $propPatch
 	 * @return void
 	 */
@@ -456,6 +644,16 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 		$this->sharingBackend->deleteAllShares($calendarId);
 	}
 
+	/**
+	 * Delete all of an user's shares
+	 *
+	 * @param string $principalUri
+	 * @return void
+	 */
+	function deleteAllSharesForUser($principalUri) {
+		$this->sharingBackend->deleteAllSharesByUser($principalUri);
+	}
+
 	/**
 	 * Returns all calendar objects within a calendar.
 	 *
@@ -1083,14 +1281,14 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 
 		foreach($this->subscriptionPropertyMap as $xmlName=>$dbName) {
 			if (array_key_exists($xmlName, $properties)) {
-				$values[$dbName] = $properties[$xmlName];
-				if (in_array($dbName, $propertiesBoolean)) {
-					$values[$dbName] = true;
+					$values[$dbName] = $properties[$xmlName];
+					if (in_array($dbName, $propertiesBoolean)) {
+						$values[$dbName] = true;
 				}
 			}
 		}
 
-		$valuesToInsert = array();
+		$valuesToInsert = [];
 
 		$query = $this->db->getQueryBuilder();
 
@@ -1414,6 +1612,50 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 		return $this->sharingBackend->getShares($resourceId);
 	}
 
+	/**
+	 * @param boolean $value
+	 * @param \OCA\DAV\CalDAV\Calendar $calendar
+	 * @return string|null
+	 */
+	public function setPublishStatus($value, $calendar) {
+		$query = $this->db->getQueryBuilder();
+		if ($value) {
+			$publicUri = $this->random->generate(16, ISecureRandom::CHAR_UPPER.ISecureRandom::CHAR_DIGITS);
+			$query->insert('dav_shares')
+				->values([
+					'principaluri' => $query->createNamedParameter($calendar->getPrincipalURI()),
+					'type' => $query->createNamedParameter('calendar'),
+					'access' => $query->createNamedParameter(self::ACCESS_PUBLIC),
+					'resourceid' => $query->createNamedParameter($calendar->getResourceId()),
+					'publicuri' => $query->createNamedParameter($publicUri)
+				]);
+			$query->execute();
+			return $publicUri;
+		}
+		$query->delete('dav_shares')
+			->where($query->expr()->eq('resourceid', $query->createNamedParameter($calendar->getResourceId())))
+			->andWhere($query->expr()->eq('access', $query->createNamedParameter(self::ACCESS_PUBLIC)));
+		$query->execute();
+		return null;
+	}
+
+	/**
+	 * @param \OCA\DAV\CalDAV\Calendar $calendar
+	 * @return mixed
+	 */
+	public function getPublishStatus($calendar) {
+		$query = $this->db->getQueryBuilder();
+		$result = $query->select('publicuri')
+			->from('dav_shares')
+			->where($query->expr()->eq('resourceid', $query->createNamedParameter($calendar->getResourceId())))
+			->andWhere($query->expr()->eq('access', $query->createNamedParameter(self::ACCESS_PUBLIC)))
+			->execute();
+
+		$row = $result->fetch();
+		$result->closeCursor();
+		return $row ? reset($row) : false;
+	}
+
 	/**
 	 * @param int $resourceId
 	 * @param array $acl
@@ -1423,10 +1665,11 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 		return $this->sharingBackend->applyShareAcl($resourceId, $acl);
 	}
 
-	private function convertPrincipal($principalUri, $toV2) {
+	private function convertPrincipal($principalUri, $toV2 = null) {
 		if ($this->principalBackend->getPrincipalPrefix() === 'principals') {
 			list(, $name) = URLUtil::splitPath($principalUri);
-			if ($toV2 === true) {
+			$toV2 = $toV2 === null ? !$this->legacyMode : $toV2;
+			if ($toV2) {
 				return "principals/users/$name";
 			}
 			return "principals/$name";
