@@ -2,13 +2,15 @@ OC.L10N.register(
     "files",
     {
     "Unknown error" : "Unbekannter Fehler",
-    "Files" : "Dateien",
     "Download" : "Herunterladen",
+    "Rename" : "Umbenennen",
     "Delete" : "Löschen",
+    "Unshare" : "Teilung zurücknehmen",
+    "Files" : "Dateien",
     "Details" : "Details",
-    "Error" : "Fehler",
-    "Upload" : "Hochladen",
+    "Name" : "Name",
     "New folder" : "Neuer Ordner",
+    "Upload" : "Hochladen",
     "A new file or folder has been <strong>created</strong>" : "Eine neue Datei oder ein neuer Ordner wurde <strong>erstellt</strong>",
     "A file or folder has been <strong>changed</strong>" : "Eine Datei oder ein Ordner hat sich <strong>geändert</strong>",
     "A file or folder has been <strong>deleted</strong>" : "Eine Datei oder ein Ordner wurde <strong>gelöscht</strong>",
@@ -19,7 +21,6 @@ OC.L10N.register(
     "You deleted %1$s" : "Du hast %1$s gelöscht",
     "%2$s deleted %1$s" : "%2$s löschte %1$s",
     "Save" : "Speichern",
-    "Settings" : "Einstellungen",
-    "Cancel upload" : "Hochladen abbrechen"
+    "Settings" : "Einstellungen"
 },
 "nplurals=2; plural=(n != 1);");
