@@ -1,7 +1,8 @@
 OC.L10N.register(
     "files",
     {
+    "Download" : "ဒေါင်းလုတ်",
     "Files" : "ဖိုင်များ",
-    "Download" : "ဒေါင်းလုတ်"
+    "Invalid path" : "လမ်း‌ေြကာင်းမှား"
 },
 "nplurals=1; plural=0;");
