@@ -21,10 +21,12 @@
 *
 */
 
-OC::$CLASSPATH['OC_Files_Antivirus'] = OC_App::getAppPath('files_antivirus').'/lib/clamav.php';
-OC::$CLASSPATH['OC_Files_Antivirus_BackgroundScanner'] = OC_App::getAppPath('files_antivirus').'/lib/scanner.php';
+$app = new \OCA\Files_Antivirus\AppInfo\Application();
+OCP\Util::connectHook('OC_Filesystem', 'preSetup', $app, 'setupWrapper');
 
-OC_APP::registerAdmin('files_antivirus', 'settings');
-OC_Hook::connect('OC_Filesystem', 'post_write', 'OC_Files_Antivirus', 'av_scan');
-
-OCP\BackgroundJob::AddRegularTask('OC_Files_Antivirus_BackgroundScanner', 'check');
+\OC::$server->getActivityManager()->registerExtension(function() {
+		return new \OCA\Files_Antivirus\Activity(
+			\OC::$server->query('L10NFactory'),
+			\OC::$server->getURLGenerator()
+		);
+});
