@@ -8,6 +8,7 @@
 
 namespace OCA\Files_Antivirus;
 
+use OC\Files\Filesystem;
 use OC\Files\Storage\Wrapper\Wrapper;
 use \OCP\App;
 use \OCP\IConfig;
@@ -58,7 +59,10 @@ class AvirWrapper extends Wrapper{
 	 */
 	public function fopen($path, $mode){
 		$stream = $this->storage->fopen($path, $mode);
-		if (is_resource($stream) && $this->isWritingMode($mode)) {
+		if (is_resource($stream)
+			&& $this->isWritingMode($mode)
+			&& strpos($path, 'uploads/') !== 0
+		) {
 			try {
 				$scanner = $this->scannerFactory->getScanner();
 				$scanner->initScanner();
@@ -73,7 +77,10 @@ class AvirWrapper extends Wrapper{
 						if (intval($status->getNumericStatus()) === \OCA\Files_Antivirus\Status::SCANRESULT_INFECTED){
 							//prevent from going to trashbin
 							if (App::isEnabled('files_trashbin')) {
-								\OCA\Files_Trashbin\Storage::preRenameHook([]);
+								\OCA\Files_Trashbin\Storage::preRenameHook([
+									Filesystem::signal_param_oldpath => '',
+									Filesystem::signal_param_newpath => ''
+								]);
 							}
 							
 							$owner = $this->getOwner($path);
@@ -82,7 +89,12 @@ class AvirWrapper extends Wrapper{
 							if (App::isEnabled('files_trashbin')) {
 								\OCA\Files_Trashbin\Storage::postRenameHook([]);
 							}
-							
+							$this->logger->warning(
+								'Infected file deleted. ' . $status->getDetails()
+								. ' Account: ' . $owner . ' Path: ' . $path,
+								['app' => 'files_antivirus']
+							);
+
 							\OC::$server->getActivityManager()->publishActivity(
 								'files_antivirus',
 								Activity::SUBJECT_VIRUS_DETECTED,
