@@ -4,31 +4,24 @@ OC.L10N.register(
     "Step 1 failed. Exception: %s" : "El pas 1 ha fallat. Excepció: %s",
     "Step 2 failed. Exception: %s" : "El pas 2 ha fallat. Excepció: %s",
     "External storage" : "Emmagatzemament extern",
-    "Storage with id \"%i\" not found" : "No s'ha trobat emmagatzematge amb id \"%i\"",
-    "Invalid mount point" : "Punt de muntatge no vàlid",
-    "Invalid storage backend \"%s\"" : "Motor d'emmagatzematge no vàlid \"%s\"",
     "Personal" : "Personal",
     "System" : "Sistema",
     "Grant access" : "Concedeix accés",
-    "Access granted" : "S'ha concedit l'accés",
     "Generate keys" : "Generar claus",
     "Error generating key pair" : "Error en generar el parell de claus",
-    "Enable encryption" : "Habilitar xifrat",
-    "Enable previews" : "Habilitar vistes prèvies",
-    "Check for changes" : "Comproveu si hi ha canvis",
-    "Never" : "Mai",
-    "Once every direct access" : "Un cop cada accés directe",
-    "Every time the filesystem is used" : "Cada vegada que s'utilitza el sistema d'arxius",
     "All users. Type to select user or group." : "Tots els usuaris. Escriu per seleccionar un usuari o grup.",
     "(group)" : "(grup)",
     "Saved" : "Desat",
-    "None" : "Cap",
+    "Username" : "Nom d'usuari",
+    "Password" : "Contrasenya",
+    "Save" : "Desa",
+    "Storage with id \"%i\" not found" : "No s'ha trobat emmagatzematge amb id \"%i\"",
+    "Invalid mount point" : "Punt de muntatge no vàlid",
+    "Invalid storage backend \"%s\"" : "Motor d'emmagatzematge no vàlid \"%s\"",
     "App key" : "Clau de l'aplicació",
     "App secret" : "Secret de l'aplicació",
     "Client ID" : "Client ID",
     "Client secret" : "Secret del client",
-    "Username" : "Nom d'usuari",
-    "Password" : "Contrasenya",
     "API key" : "codi API",
     "Public key" : "Clau pública",
     "Amazon S3" : "Amazon S3",
@@ -42,11 +35,10 @@ OC.L10N.register(
     "URL" : "URL",
     "Remote subfolder" : "Subcarpeta remota",
     "Secure https://" : "Protocol segur https://",
-    "Host" : "Equip remot",
-    "Secure ftps://" : "Protocol segur ftps://",
     "Local" : "Local",
     "Location" : "Ubicació",
     "ownCloud" : "ownCloud",
+    "Host" : "Equip remot",
     "Root" : "Arrel",
     "SFTP with secret key login" : "Inici de sessió SFTP amb clau secreta",
     "Share" : "Comparteix",
@@ -55,21 +47,23 @@ OC.L10N.register(
     "OpenStack Object Storage" : "OpenStack Object Storage",
     "<b>Note:</b> " : "<b>Nota:</b> ",
     "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Nota:</b> El suport cURL no està activat o instal·lat a PHP. No es pot muntar %s. Demaneu a l'administrador del sistema que l'instal·li.",
-    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Nota:</b> El suport FTP per PHP no està activat o no està instal·lat. No es pot muntar %s. Demaneu a l'administrador del sistema que l'instal·li.",
     "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Nota:</b> %s no està instal·lat. No es pot muntar %s. Demaneu a l'administrador del sistema que l'instal·li.",
     "No external storage configured" : "Sense emmagatzematge extern configurat",
-    "You can add external storages in the personal settings" : "Pot agregar emmagatzematges externs en la configuració personal",
     "Name" : "Nom",
     "Storage type" : "Tipus d'emmagatzemament",
     "Scope" : "Abast",
+    "Enable encryption" : "Habilitar xifrat",
+    "Enable previews" : "Habilitar vistes prèvies",
+    "Check for changes" : "Comproveu si hi ha canvis",
+    "Never" : "Mai",
+    "Once every direct access" : "Un cop cada accés directe",
     "External Storage" : "Emmagatzemament extern",
     "Folder name" : "Nom de la carpeta",
     "Configuration" : "Configuració",
     "Available for" : "Disponible per",
+    "Add storage" : "Afegeix emmagatzemament",
     "Advanced settings" : "Configuració avançada",
     "Delete" : "Esborra",
-    "Add storage" : "Afegeix emmagatzemament",
-    "Enable User External Storage" : "Habilita l'emmagatzemament extern d'usuari",
     "Allow users to mount the following external storage" : "Permet als usuaris muntar els dispositius externs següents"
 },
 "nplurals=2; plural=(n != 1);");
