@@ -21,13 +21,14 @@ OC.L10N.register(
     "Compatibility with Mac NFD encoding (slow)" : "ความเข้ากันได้กับการเข้ารหัส Mac NFS (ช้า)",
     "Admin defined" : "ถูกกำหนดโดยผู้ดูแลระบบ",
     "Saved" : "บันทึกแล้ว",
+    "Disabling external storage will unmount all storages for all users, are you sure ?" : "หากปิดการใช้งานการจัดเก็บข้อมูลภายนอก ข้อมูลของผู้ใช้ทั้งหมดจะถูกยกเลิกการต่อเชื่อม คุณแน่ใจ?",
+    "Disable external storage" : "ปิดการใช้งานพื้นที่จัดเก็บข้อมูลภายนอก",
     "Empty response from the server" : "ไม่มีการตอบสนองจากเซิร์ฟเวอร์",
     "Couldn't access. Please logout and login to activate this mount point" : "ไม่สามารถเข้าถึง กรุณออกจากระบบและาเข้าสู่ระบบใหม่เพื่อเปิดใช้งานจุดเชื่อมต่อนี้",
     "Couldn't get the information from the ownCloud server: {code} {type}" : "ไม่สามารถรับข้อมูลจากเซิร์ฟเวอร์ ownCloud: {code} {type}",
     "Couldn't get the list of external mount points: {type}" : "ไม่สามารถรับรายชื่อของจุดเชื่อมต่อภายนอก: {type}",
     "There was an error with message: " : "มีข้อความแสดงข้อผิดพลาด",
     "External mount error" : "การติดจากตั้งภายนอกเกิดข้อผิดพลาด",
-    "external-storage" : "ที่จัดเก็บข้อมูลภายนอก",
     "Couldn't get the list of Windows network drive mount points: empty response from the server" : "ไม่สามารถรับรายชื่อไดรฟ์เครือข่ายของวินโดว์ส จุดที่ติดตั้ง: ไม่มีการตอบสนองจากเซิร์ฟเวอร์",
     "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "การกำหนดค่าบางส่วนของจุดเชื่อมต่อภายนอกไม่ถูกเชื่อมต่อ กรุณาคลิกที่ตรงสีแดงสำหรับข้อมูลเพิ่มเติม",
     "Please enter the credentials for the {mount} mount" : "กรุณากรอกข้อมูลประจำตัวสำหรับ {mount} ",
@@ -51,8 +52,6 @@ OC.L10N.register(
     "Storage with id \"%i\" is not user editable" : "พื้นที่เก็บข้อมูล รหัส \"%i\" ไม่อนุญาตให้ผู้ใช้แก้ไขข้อมูลได้",
     "Access key" : "คีย์การเข้าถึง",
     "Secret key" : "คีย์ลับ",
-    "Builtin" : "ในตัว",
-    "None" : "ไม่มี",
     "OAuth1" : "OAuth1",
     "App key" : "App key",
     "App secret" : "App secret",
@@ -64,8 +63,6 @@ OC.L10N.register(
     "Identity endpoint URL" : "ตัวตนของ URL ปลายทาง",
     "Rackspace" : "Rackspace",
     "API key" : "รหัส API",
-    "Username and password" : "ชื่อผู้ใช้และรหัสผ่าน",
-    "Log-in credentials, save in session" : "ข้อมูลประจำตัวสำหรับเข้าสู่ระบบ, บันทึกลงในช่วงเวลาเข้าใช้งาน",
     "RSA public key" : "RSA คีย์สาธารณะ",
     "Public key" : "คีย์สาธารณะ",
     "Amazon S3" : "Amazon S3",
@@ -80,14 +77,12 @@ OC.L10N.register(
     "Remote subfolder" : "โฟลเดอร์ย่อยรีโมท",
     "Secure https://" : "โหมดปลอดภัย https://",
     "Dropbox" : "Dropbox",
-    "FTP" : "FTP",
-    "Host" : "โฮสต์",
-    "Secure ftps://" : "โหมดปลอดภัย ftps://",
     "Google Drive" : "กูเกิ้ลไดร์ฟ",
     "Local" : "ต้นทาง",
     "Location" : "ตำแหน่งที่อยู่",
     "ownCloud" : "ownCloud",
     "SFTP" : "SFTP",
+    "Host" : "โฮสต์",
     "Root" : "รูท",
     "SFTP with secret key login" : "SFTP กับคีย์ลับสำหรับเข้าสู่ระบบ",
     "SMB / CIFS" : "SMB / CIFS",
@@ -100,10 +95,9 @@ OC.L10N.register(
     "Request timeout (seconds)" : "หมดเวลาการร้องขอ (วินาที)",
     "<b>Note:</b> " : "<b>หมายเหตุ:</b>",
     "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>หมายเหตุ:</b> การสนับสนุน cURL ใน PHP ไม่ได้เปิดใช้งานหรือติดตั้ง %s เป็นไปไม่ได้ กรุณาขอให้ผู้ดูแลระบบของคุณติดตั้งมัน",
-    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>หมายเหตุ:</b> การสนับสนุน FTP ใน PHP ไม่ได้เปิดใช้งานหรือติดตั้ง %s เป็นไปไม่ได้ กรุณาขอให้ผู้ดูแลระบบของคุณติดตั้งมัน",
     "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>หมายเหตุ:</b> %s ไม่ได้ติดตั้ง การติดตั้ง %s เป็นไปไม่ได้ กรุณาขอให้ผู้ดูแลระบบของคุณติดตั้งมัน",
     "No external storage configured" : "ไม่มีการกำหนดค่าจัดเก็บข้อมูลภายนอก",
-    "You can add external storages in the personal settings" : "คุณสามารถเพิ่มการเก็บรักษาภายนอกในการตั้งค่าส่วนบุคคล",
+    "You can add external storages in the storage settings" : "คุณสามารถเพิ่มการจัดเก็บข้อมูลภายนอกในการตั้งค่าพื้นที่เก็บข้อมูลได้",
     "Name" : "ชื่อ",
     "Storage type" : "ชนิดการจัดเก็บข้อมูล",
     "Scope" : "ขอบเขต",
@@ -114,6 +108,8 @@ OC.L10N.register(
     "Never" : "ไม่เคย",
     "Once every direct access" : "เมื่อทุกคนเข้าถึงโดยตรง",
     "External Storage" : "พื้นทีจัดเก็บข้อมูลจากภายนอก",
+    "Enable external storage" : "เปิดการใช้งานพื้นที่จัดเก็บข้อมูลภายนอก",
+    "External storage has been disabled by the administrator" : "ผู้ดูแลระบบได้ปิดการใช้งานการจัดเก็บข้อมูลภายนอก",
     "Folder name" : "ชื่อโฟลเดอร์",
     "Authentication" : "รับรองความถูกต้อง",
     "Configuration" : "การกำหนดค่า",
