@@ -1,10 +1,13 @@
 OC.L10N.register(
     "files_sharing",
     {
+    "Uploading..." : "Yn llwytho i fyny...",
     "Cancel" : "Diddymu",
+    "Share" : "Rhannu",
     "Shared by" : "Rhannwyd gan",
     "Password" : "Cyfrinair",
     "Name" : "Enw",
+    "Expiration date" : "Dyddiad dod i ben",
     "Download" : "Llwytho i lawr"
 },
 "nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
