@@ -11,7 +11,7 @@ OC.L10N.register(
     "Shared with you" : "Gedeeld met u",
     "Shared with others" : "Gedeeld door u",
     "Shared by link" : "Gedeeld via een link",
-    "Federated sharing" : "Federated sharing",
+    "Uploading..." : "Uploading...",
     "Nothing shared with you yet" : "Nog niets met u gedeeld",
     "Files and folders others share with you will show up here" : "Bestanden en mappen die anderen met u delen, worden hier getoond",
     "Nothing shared yet" : "Nog niets gedeeld",
@@ -26,8 +26,29 @@ OC.L10N.register(
     "You can upload into this folder" : "U kunt uploaden naar deze map",
     "No ownCloud installation (7 or higher) found at {remote}" : "Geen recente ownCloud installatie (7 of hoger) gevonden op {remote}",
     "Invalid ownCloud url" : "Ongeldige ownCloud url",
+    "Share" : "Deel",
+    "No expiration date set" : "Geen vervaldatum ingesteld",
     "Shared by" : "Gedeeld door",
     "Sharing" : "Delen",
+    "Share API is disabled" : "Delen API is uitgeschakeld",
+    "Wrong share ID, share doesn't exist" : "Onjuist deel-ID, de share bestaat niet",
+    "Could not delete share" : "Kon share niet verwijderen",
+    "Please specify a file or folder path" : "Geef een bestand of pad van een map op",
+    "Wrong path, file/folder doesn't exist" : "Onjuist pad, bestand/map bestaat niet",
+    "Please specify a valid user" : "Geef een geldige gebruiker op",
+    "Group sharing is disabled by the administrator" : "Delen voor groepen is uitgeschakeld door de beheerder",
+    "Please specify a valid group" : "Geef een geldige groep op",
+    "Public link sharing is disabled by the administrator" : "Delen van openbare links is uitgeschakeld door de beheerder",
+    "Public upload disabled by the administrator" : "Publieke upload uitgeschakeld door de systeembeheerder",
+    "Public upload is only possible for publicly shared folders" : "Publieke upload is alleen mogelijk voor publiek gedeelde mappen",
+    "Invalid date, date format must be YYYY-MM-DD" : "Ongeldige datum, datumnotatie moet in de vorm YYYY-MM-DD",
+    "Sharing %s failed because the back end does not allow shares from type %s" : "Delen van %s mislukte omdat de backend het delen van type %s niet ondersteunt",
+    "Unknown share type" : "Onbekend type share",
+    "Not a directory" : "Geen directory",
+    "Could not lock path" : "Kon pad niet blokkeren",
+    "Can't change permissions for public share links" : "Kan permissies voor openbare share links niet wijzigen",
+    "Wrong or no update parameter given" : "Verkeerde of geen update parameter gegeven",
+    "Cannot increase permissions" : "Kan de rechten niet verruimen",
     "A file or folder has been <strong>shared</strong>" : "Een bestand of map is <strong>gedeeld</strong>",
     "A file or folder was shared from <strong>another server</strong>" : "Een bestand of map werd gedeeld vanaf <strong>een andere server</strong>",
     "A public shared file or folder was <strong>downloaded</strong>" : "Een openbaar gedeeld bestand of map werd <strong>gedownloaded</strong>",
@@ -35,7 +56,7 @@ OC.L10N.register(
     "You received a new remote share from %s" : "U ontving een nieuwe externe share van %s",
     "%1$s accepted remote share %2$s" : "%1$s accepteerde externe share %2$s",
     "%1$s declined remote share %2$s" : "%1$s weigerde externe share %2$s",
-    "%1$s unshared %2$s from you" : "%1$s stopte met delen van %2$s met je",
+    "%1$s unshared %2$s from you" : "%1$s stopte met delen met u van %2$s",
     "Public shared folder %1$s was downloaded" : "Openbaar gedeelde map %1$s werd gedownloaded",
     "Public shared file %1$s was downloaded" : "Openbaar gedeeld bestand %1$s werd gedownloaded",
     "You shared %1$s with %2$s" : "U deelde %1$s met %2$s",
@@ -71,49 +92,23 @@ OC.L10N.register(
     "Public link of %2$s expired" : "Openbare link van %2$s is verlopen",
     "Shared by %2$s" : "Gedeeld door %2$s",
     "Shares" : "Gedeeld",
-    "You received \"/%2$s\" as a remote share from %1$s" : "U ontving \"/%2$s\" als een externe share van %1$s",
-    "Accept" : "Accepteren",
-    "Decline" : "Afwijzen",
-    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Deel met mij via mijn #ownCloud federated Cloud ID, zie %s",
-    "Share with me through my #ownCloud Federated Cloud ID" : "Deel met mij via mijn #ownCloud federated Cloud ID",
     "This share is password-protected" : "Deze share is met een wachtwoord beveiligd",
     "The password is wrong. Try again." : "Wachtwoord ongeldig. Probeer het nogmaals.",
     "Password" : "Wachtwoord",
     "No entries found in this folder" : "Niets gevonden in deze map",
     "Name" : "Naam",
     "Share time" : "Deel tijd",
+    "Expiration date" : "Vervaldatum",
     "Sorry, this link doesn’t seem to work anymore." : "Sorry, deze link lijkt niet meer in gebruik te zijn.",
     "Reasons might be:" : "Redenen kunnen zijn:",
     "the item was removed" : "bestand was verwijderd",
     "the link expired" : "de link is verlopen",
     "sharing is disabled" : "delen is uitgeschakeld",
     "For more info, please ask the person who sent this link." : "Voor meer informatie, neem contact op met de persoon die u deze link heeft gestuurd.",
+    "%s is publicly shared" : "%s is openbaar gedeeld",
     "Add to your ownCloud" : "Toevoegen aan uw ownCloud",
     "Download" : "Downloaden",
     "Download %s" : "Download %s",
-    "Direct link" : "Directe link",
-    "Federated Cloud Sharing" : "Federated Cloud Sharing",
-    "Open documentation" : "Open documentatie",
-    "Allow users on this server to send shares to other servers" : "Toestaan dat gebruikers op deze server shares sturen naar andere servers",
-    "Allow users on this server to receive shares from other servers" : "Toestaan dat gebruikers op deze server shares ontvangen van andere servers",
-    "Federated Cloud" : "Gefedereerde Cloud",
-    "Your Federated Cloud ID:" : "Uw Federated Cloud ID:",
-    "Share it:" : "Deel het:",
-    "Add to your website" : "Toevoegen aan uw website",
-    "Share with me via ownCloud" : "Deel met mij via ownCloud",
-    "HTML Code:" : "HTML Code:",
-    "Public link of %2$s expired" : "Openbare link van %2$s is verlopen",
-    "Public shared file %1$s was downloaded" : "Openbaar gedeeld bestand %1$s werd gedownloaded",
-    "Public shared folder %1$s was downloaded" : "Openbaar gedeelde map %1$s werd gedownloaded",
-    "Removed share for %2$s" : "Share van %2$s verwijderd",
-    "Removed share of group %2$s" : "Share van de groep %2$s verwijderd",
-    "Shared by %2$s" : "Gedeeld door %2$s",
-    "Shared via link by %2$s" : "Gedeeld via link door %2$s",
-    "Shared with group %3$s by %2$s" : "Gedeeld met groep %3$s door %2$s",
-    "The public link of %2$s for %1$s expired" : "De openbare link van %2$s voor %1$s is verlopen",
-    "You removed the public link for %1$s" : "U heeft de openbare link voor %1$s verwijderd",
-    "You removed the share of %2$s for %1$s" : "U heeft de share van %1$s met %2$s verwijderd",
-    "You removed the share of group %2$s for %1$s" : "U heeft de share van %1$s met de groep %2$s verwijderd",
-    "Your public link for %1$s expired" : "Uw openbare link voor %1$s is verlopen"
+    "Direct link" : "Directe link"
 },
 "nplurals=2; plural=(n != 1);");
