@@ -4,8 +4,9 @@ OC.L10N.register(
     "Could not revert: %s" : "Impossible de restablir %s",
     "Versions" : "Versions",
     "Failed to revert {file} to revision {timestamp}." : "Fracàs del retorn del fichièr {file} a la revision {timestamp}.",
-    "More versions..." : "Mai de versions...",
+    "_%n byte_::_%n bytes_" : ["%n octet","%n octets"],
+    "Restore" : "Restablir",
     "No other versions available" : "Cap d'autra version es pas disponibla",
-    "Restore" : "Restablir"
+    "More versions..." : "Mai de versions..."
 },
 "nplurals=2; plural=(n > 1);");
