@@ -6,11 +6,6 @@ function showfirstrunwizard(){
 		width:"70%", 
 		height:"70%", 
 		href: OC.filePath('firstrunwizard', '', 'wizard.php'),
-		onComplete : function(){
-			if (!SVGSupport()) {
-				replaceSVG();
-			}
-		},
 		onClosed : function(){
 			$.ajax({
 			url: OC.filePath('firstrunwizard', 'ajax', 'disable.php'),
@@ -26,4 +21,4 @@ $('#showWizard').live('click', function () {
 
 $('#closeWizard').live('click', function () {	
 		$.colorbox.close();
-});
\ No newline at end of file
+});
