@@ -3,7 +3,7 @@ OC.L10N.register(
     {
     "Could not load template" : "Šablonu nelze nahrát",
     "Saved" : "Uloženo",
-    "Reset" : "Restartovat složku",
+    "Reset" : "Reset",
     "An error occurred" : "Nastala chyba",
     "Sharing email - public link shares (HTML)" : "Email o sdílení - sdíleno veřejným odkazem (HTML)",
     "Sharing email - public link shares (plain text fallback)" : "Email o sdílení - sdíleno veřejným odkazem (čistý text)",
