@@ -12,16 +12,8 @@ OC.L10N.register(
     "Crop is not square" : "El retall no és quadrat",
     "Couldn't reset password because the token is invalid" : "No es pot restablir la contrasenya perquè el testimoni no és vàlid",
     "Couldn't reset password because the token is expired" : "No es pot restablir la contrasenya perquè el testimoni ha vençut",
-    "Couldn't send reset email. Please make sure your username is correct." : "No s'ha pogut enviar el correu de restabliment. Assegureu-vos que el vostre nom d'usuari és correcte.",
     "%s password reset" : "restableix la contrasenya %s",
     "Couldn't send reset email. Please contact your administrator." : "No s'ha pogut restablir el correu. Contacteu amb l'administrador.",
-    "Error loading tags" : "Error en carregar les etiquetes",
-    "Tag already exists" : "L'etiqueta ja existeix",
-    "Error deleting tag(s)" : "Error en eliminar etiqueta(s)",
-    "Error tagging" : "Error en etiquetar",
-    "Error untagging" : "Error en treure les etiquetes",
-    "Error favoriting" : "Error en posar a preferits",
-    "Error unfavoriting" : "Error en treure de preferits",
     "Couldn't send mail to following users: %s " : "No s'ha pogut enviar correu als usuaris següents: %s",
     "Preparing update" : "Preparant l'actualització",
     "Repair warning: " : "Advertiment de reparació:",
@@ -120,22 +112,22 @@ OC.L10N.register(
     "Error" : "Error",
     "Error while sharing" : "Error en compartir",
     "Error while unsharing" : "Error en deixar de compartir",
-    "Error setting expiration date" : "Error en establir la data de venciment",
     "The public link will expire no later than {days} days after it is created" : "L'enllaç públic tindrà venciment abans de {days} dies després de crear-lo",
     "Set expiration date" : "Estableix la data de venciment",
     "Expiration" : "Expiració",
     "Expiration date" : "Data de venciment",
-    "Choose a password for the public link" : "Escolliu una contrasenya per l'enllaç públic",
-    "Resharing is not allowed" : "No es permet compartir de nou",
-    "Share link" : "Enllaç de compartició",
     "Link" : "Enllaç",
-    "Password protect" : "Protegir amb contrasenya",
+    "Edit" : "Editar",
+    "Remove" : "Elimina",
+    "Choose a password for the public link" : "Escolliu una contrasenya per l'enllaç públic",
+    "Filename" : "Nom del fitxer",
     "Password" : "Contrasenya",
+    "Name" : "Nom",
     "Allow editing" : "Permetre edició",
-    "Email link to person" : "Enllaç per correu electrónic amb la persona",
-    "Send" : "Envia",
+    "Save" : "Desar",
     "Sending ..." : "Enviant...",
     "Email sent" : "El correu electrónic s'ha enviat",
+    "Email link to person" : "Enllaç per correu electrónic amb la persona",
     "Shared with you and the group {group} by {owner}" : "Compartit amb vos i amb el grup {group} per {owner}",
     "Shared with you by {owner}" : "Compartit amb vos per {owner}",
     "group" : "grup",
@@ -149,6 +141,7 @@ OC.L10N.register(
     "delete" : "elimina",
     "access control" : "control d'accés",
     "Share" : "Comparteix",
+    "Resharing is not allowed" : "No es permet compartir de nou",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Compartir amb la gent en altres ownClouds utilitzant la sintaxi username@example.com/owncloud",
     "Warning" : "Avís",
     "Delete" : "Esborra",
@@ -195,8 +188,6 @@ OC.L10N.register(
     "File: %s" : "Fitxer: %s",
     "Line: %s" : "Línia: %s",
     "Trace" : "Traça",
-    "Security warning" : "Advertiment de seguretat",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "La carpeta de dades i els seus fitxers probablement són accessibles des d'internet perquè el fitxer .htaccess no funciona.",
     "Create an <strong>admin account</strong>" : "Crea un <strong>compte d'administrador</strong>",
     "Username" : "Nom d'usuari",
     "Storage & database" : "Emmagatzematge i base de dades",
@@ -244,7 +235,6 @@ OC.L10N.register(
     "App update required" : "Cal que actualitzeu la aplicació",
     "%s will be updated to version %s" : "%s s'actualitzarà a la versió %s",
     "These apps will be updated:" : "Aquestes aplicacions s'actualitzaran:",
-    "These incompatible apps will be disabled:" : "Aquestes aplicacions incompatibles es desactivaran:",
     "The theme %s has been disabled." : "S'ha desactivat el tema %s",
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Assegureu-vos que heu fet una còpia de seguretat de la base de dades, del fitxer de configuració i de la carpeta de dades abans de continuar.",
     "Start update" : "Inicia l'actualització",
