@@ -52,17 +52,17 @@ OC.L10N.register(
     "Error" : "შეცდომა",
     "Error while sharing" : "შეცდომა გაზიარების დროს",
     "Error while unsharing" : "შეცდომა გაზიარების გაუქმების დროს",
-    "Error setting expiration date" : "შეცდომა ვადის გასვლის მითითების დროს",
     "Set expiration date" : "მიუთითე ვადის გასვლის დრო",
     "Expiration" : "ვადის გასვლის დრო",
     "Expiration date" : "ვადის გასვლის დრო",
+    "Edit" : "რედაქტირება",
+    "Remove" : "წაშლა",
+    "Password" : "პაროლი",
+    "Name" : "სახელი",
+    "Save" : "შენახვა",
     "Sending ..." : "გაგზავნა ....",
     "Email sent" : "იმეილი გაიგზავნა",
-    "Resharing is not allowed" : "მეორეჯერ გაზიარება არ არის დაშვებული",
-    "Password protect" : "პაროლით დაცვა",
-    "Password" : "პაროლი",
     "Email link to person" : "ლინკის პიროვნების იმეილზე გაგზავნა",
-    "Send" : "გაგზავნა",
     "Shared with you and the group {group} by {owner}" : "გაზიარდა თქვენთვის და ჯგუფისთვის {group}, {owner}–ის მიერ",
     "Shared with you by {owner}" : "გაზიარდა თქვენთვის {owner}–ის მიერ",
     "group" : "ჯგუფი",
@@ -72,11 +72,13 @@ OC.L10N.register(
     "delete" : "წაშლა",
     "access control" : "დაშვების კონტროლი",
     "Share" : "გაზიარება",
+    "Resharing is not allowed" : "მეორეჯერ გაზიარება არ არის დაშვებული",
     "Warning" : "გაფრთხილება",
     "Delete" : "წაშლა",
     "Rename" : "გადარქმევა",
     "The object type is not specified." : "ობიექტის ტიპი არ არის მითითებული.",
     "Add" : "დამატება",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "განახლება ვერ განხორციელდა. გთხოვთ შეგვატყობინოთ ამ პრობლემის შესახებ აქ: <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>.",
     "The update was successful. Redirecting you to ownCloud now." : "განახლება ვერ განხორციელდა. გადამისამართება თქვენს ownCloud–ზე.",
     "Personal" : "პირადი",
     "Users" : "მომხმარებელი",
@@ -84,7 +86,6 @@ OC.L10N.register(
     "Admin" : "ადმინისტრატორი",
     "Help" : "დახმარება",
     "Access forbidden" : "წვდომა აკრძალულია",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "თქვენი data დირექტორია და ფაილები დაშვებადია ინტერნეტში რადგან  .htaccess ფაილი არ მუშაობს.",
     "Create an <strong>admin account</strong>" : "შექმენი <strong>ადმინ ექაუნტი</strong>",
     "Username" : "მომხმარებლის სახელი",
     "Data folder" : "მონაცემთა საქაღალდე",
