@@ -1,29 +1,6 @@
 OC.L10N.register(
     "core",
     {
-    "Couldn't send mail to following users: %s " : "ไม่สามารถส่งอีเมลไปยังผู้ใช้: %s",
-    "Preparing update" : "เตรียมอัพเดท",
-    "Turned on maintenance mode" : "เปิดโหมดการบำรุงรักษา",
-    "Turned off maintenance mode" : "ปิดโหมดการบำรุงรักษา",
-    "Maintenance mode is kept active" : "โหมดการบำรุงรักษาจะถูกเก็บไว้ใช้งาน",
-    "Updating database schema" : "กำลังอัพเดทฐานข้อมูล schema",
-    "Updated database" : "ปรับปรุงฐานข้อมูล",
-    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "กำลังตรวจสอบว่าฐานข้อมูล schema สามารถอัพเดทได้หรือไม่ (นี้อาจใช้เวลานานขึ้นอยู่กับขนาดของฐานข้อมูล)",
-    "Checked database schema update" : "Schema อัพเดตของฐานข้อมูลถูกตรวจสอบ",
-    "Checking updates of apps" : "กำลังตรวจสอบการอัพเดทแอพพลิเคชัน",
-    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "กำลังตรวจสอบว่าฐานข้อมูลสำหรับ schema สำหรับ %s ว่าสามารถอัพเดทได้หรือไม่ (นี้จะใช้เวลานานขึ้นอยู่กับขนาดของฐานข้อมูล)",
-    "Checked database schema update for apps" : "Schema อัพเดตของฐานข้อมูลสำหรับแอพฯ",
-    "Updated \"%s\" to %s" : "อัพเดท \"%s\" ไปยัง %s",
-    "Repair warning: " : "เตือนการซ่อมแซม:",
-    "Repair error: " : "เกิดข้อผิดพลาดในการซ่อมแซม:",
-    "Set log level to debug" : "ตั้งค่าระดับบันทึกเพื่อแก้ปัญหา",
-    "Reset log level" : "ตั้งค่าระดับบันทึกใหม่",
-    "Starting code integrity check" : "กำลังเริ่มต้นรหัสตรวจสอบความสมบูรณ์",
-    "Finished code integrity check" : "ตรวจสอบความสมบูรณ์ของรหัสเสร็จสิ้น",
-    "%s (3rdparty)" : "%s (บุคคลที่ 3)",
-    "%s (incompatible)" : "%s (เข้ากันไม่ได้)",
-    "Following apps have been disabled: %s" : "แอพฯดังต่อไปนี้ถูกปิดการใช้งาน: %s",
-    "Already up to date" : "มีอยู่แล้วถึงวันที่",
     "Please select a file." : "กรุณาเลือกแฟ้ม",
     "File is too big" : "ไฟล์มีขนาดใหญ่เกินไป",
     "Invalid file provided" : "ระบุไฟล์ไม่ถูกต้อง",
@@ -37,10 +14,35 @@ OC.L10N.register(
     "Crop is not square" : "การครอบตัดไม่เป็นสี่เหลี่ยม",
     "Couldn't reset password because the token is invalid" : "ไม่สามารถตั้งรหัสผ่านใหม่เพราะโทเค็นไม่ถูกต้อง",
     "Couldn't reset password because the token is expired" : "ไม่สามารถตั้งค่ารหัสผ่านเพราะโทเค็นหมดอายุ",
-    "Couldn't send reset email. Please make sure your username is correct." : "ไม่สามารถส่งการตั้งค่าอีเมลใหม่ กรุณาตรวจสอบชื่อผู้ใช้ของคุณให้ถูกต้อง",
-    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "ไม่ควร",
+    "%s password changed successfully" : "เปลี่ยนรหัสผ่าน %s สำเร็จแล้ว",
     "%s password reset" : "%s ตั้งรหัสผ่านใหม่",
-    "Couldn't send reset email. Please contact your administrator." : "ไม่สามารถส่งการตั้งค่าอีเมลใหม่ กรุณาติดต่อผู้ดูแลระบบ",
+    "Couldn't send reset email. Please contact your administrator." : "ไม่สามารถส่งข้อมูลการตั้งค่าไปยังอีเมลของคุณ กรุณาติดต่อผู้ดูแลระบบ",
+    "Couldn't send mail to following users: %s " : "ไม่สามารถส่งอีเมลไปยังผู้ใช้: %s",
+    "Preparing update" : "เตรียมอัพเดท",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair warning: " : "เตือนการซ่อมแซม:",
+    "Repair error: " : "เกิดข้อผิดพลาดในการซ่อมแซม:",
+    "Please use the command line updater because automatic updating is disabled in the config.php." : "กรุณาใช้คำสั่งอัพเดทเพราะการอัพเดทอัตโนมัติถูกปิดใช้งานใน config.php",
+    "[%d / %d]: Checking table %s" : "[%d / %d]: กำลังตรวจสอบตาราง %s",
+    "Turned on maintenance mode" : "เปิดโหมดการบำรุงรักษา",
+    "Turned off maintenance mode" : "ปิดโหมดการบำรุงรักษา",
+    "Maintenance mode is kept active" : "โหมดการบำรุงรักษาจะถูกเก็บไว้ใช้งาน",
+    "Updating database schema" : "กำลังอัพเดทฐานข้อมูล schema",
+    "Updated database" : "อัพเดทฐานข้อมูลเรียบร้อยแล้ว",
+    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "กำลังตรวจสอบว่าฐานข้อมูล schema สามารถอัพเดทได้หรือไม่ (นี้อาจใช้เวลานานขึ้นอยู่กับขนาดของฐานข้อมูล)",
+    "Checked database schema update" : "Schema อัพเดตของฐานข้อมูลถูกตรวจสอบ",
+    "Checking updates of apps" : "กำลังตรวจสอบการอัพเดทแอพพลิเคชัน",
+    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "กำลังตรวจสอบว่าฐานข้อมูลสำหรับ schema สำหรับ %s ว่าสามารถอัพเดทได้หรือไม่ (นี้จะใช้เวลานานขึ้นอยู่กับขนาดของฐานข้อมูล)",
+    "Checked database schema update for apps" : "Schema อัพเดตของฐานข้อมูลสำหรับแอพฯ",
+    "Updated \"%s\" to %s" : "อัพเดท \"%s\" ไปยัง %s",
+    "Set log level to debug" : "ตั้งค่าระดับของไฟล์ log เพื่อแก้ไขปัญหา",
+    "Reset log level" : "ตั้งค่าระดับของไฟล์ log ใหม่",
+    "Starting code integrity check" : "กำลังเริ่มต้นรหัสตรวจสอบความสมบูรณ์",
+    "Finished code integrity check" : "ตรวจสอบความสมบูรณ์ของรหัสเสร็จสิ้น",
+    "%s (3rdparty)" : "%s (บุคคลที่ 3)",
+    "%s (incompatible)" : "%s (เข้ากันไม่ได้)",
+    "Following apps have been disabled: %s" : "แอพฯดังต่อไปนี้ถูกปิดการใช้งาน: %s",
+    "Already up to date" : "มีอยู่แล้วถึงวันที่",
     "Sunday" : "วันอาทิตย์",
     "Monday" : "วันจันทร์",
     "Tuesday" : "วันอังคาร",
@@ -88,74 +90,101 @@ OC.L10N.register(
     "Dec." : "ธ.ค.",
     "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">มีปัญหาเกี่ยวกับการตรวจสอบความสมบูรณ์ของรหัส รายละเอียดเพิ่มเติม...</a>",
     "Settings" : "ตั้งค่า",
+    "Problem loading page, reloading in 5 seconds" : "เกิดปัญหาขณะโหลดหน้าเว็บ จะรีโหลดหน้าเว็บภายใน 5 วินาที",
     "Saving..." : "กำลังบันทึกข้อมูล...",
     "Dismiss" : "ยกเลิก",
     "seconds ago" : "วินาที ก่อนหน้านี้",
-    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "ลิงค์ที่ใช้สำหรับตั้งค่ารหัสผ่านใหม่ ของคุณ ได้ถูกส่งไปยังอีเมลของคุณ หากคุณยังไม่ได้รับอีกเมล ลองไปดูที่โฟลเดอร์ สแปม/ถังขยะ ในอีเมลของคุณ <br>ทั้งนี้หากหาอีเมลไม่พบกรุณาติดต่อผู้ดูแลระบบ",
-    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "ไฟล์ของคุณจะถูกเข้ารหัส หากคุณยังไม่ได้เปิดใช้งานรหัสการกู้คืน คุณจะได้รับข้อมูลของคุณกลับมาหลังจากที่รหัสผ่านของคุณถูกรีเซ็ต<br /> หากคุณไม่แน่ใจว่าควรทำอย่างไรโปรดติดต่อผู้ดูแลระบบของคุณก่อนที่คุณจะดำเนินการต่อไป <br /> คุณต้องการดำเนินการต่อ?",
+    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "ลิงค์ที่ใช้สำหรับตั้งค่ารหัสผ่านใหม่ ของคุณ ได้ถูกส่งไปยังอีเมลของคุณ หากคุณยังไม่ได้รับอีเมล ลองไปดูที่โฟลเดอร์ สแปม/ถังขยะ ในอีเมลของคุณ <br>ทั้งนี้หากคุณหาอีเมลไม่พบกรุณาติดต่อผู้ดูแลระบบ",
+    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "ไฟล์ของคุณถูกเข้ารหัสแล้ว หากคุณยังไม่ได้เปิดใช้งานรหัสการกู้คืน คุณจะไม่ได้รับข้อมูลของคุณกลับมาหลังจากที่รหัสผ่านของคุณถูกรีเซ็ต<br /> หากคุณไม่แน่ใจว่าควรทำอย่างไรโปรดติดต่อผู้ดูแลระบบของคุณก่อนที่คุณจะดำเนินการต่อไป <br /> คุณต้องการดำเนินการต่อ?",
     "I know what I'm doing" : "ฉันรู้ว่าฉันกำลังทำอะไรอยู่",
     "Password can not be changed. Please contact your administrator." : "หากคุณไม่สามารถเปลี่ยนแปลงรหัสผ่าน กรุณาติดต่อผู้ดูแลระบบ",
     "No" : "ไม่ตกลง",
     "Yes" : "ตกลง",
     "Choose" : "เลือก",
-    "Error loading file picker template: {error}" : "เกิดข้อผิดพลาดขณะกำลังโหลดไฟล์แม่แบบ: {error}",
+    "Error loading file picker template: {error}" : "เกิดข้อผิดพลาดขณะกำลังโหลดไฟล์เทมเพลต: {error}",
     "Ok" : "ตกลง",
-    "Error loading message template: {error}" : "เกิดข้อผิดพลาดขณะกำลังโหลดแม่แบบ: {error} ",
+    "Error loading message template: {error}" : "เกิดข้อผิดพลาดขณะกำลังโหลดเทมเพลต: {error} ",
     "read-only" : "อ่านอย่างเดียว",
     "_{count} file conflict_::_{count} file conflicts_" : ["ไฟล์มีปัญหา {count} ไฟล์"],
     "One file conflict" : "มีหนึ่งไฟล์ที่มีปัญหา",
-    "New Files" : "ไฟล์ใหม่",
-    "Already existing files" : "มีไฟล์อยู่แล้ว",
+    "New Files" : "วางทับไฟล์เดิม",
+    "Already existing files" : "เขียนไฟล์ใหม่",
     "Which files do you want to keep?" : "คุณต้องการเก็บไฟล์?",
-    "If you select both versions, the copied file will have a number added to its name." : "หากคุณเลือกทั้งสองรุ่น การคัดลอกไฟล์จะเพิ่มจำนวนไปยังชื่อของมัน",
+    "If you select both versions, the copied file will have a number added to its name." : "เลือกวางทับไฟล์เดิมหรือ เขียนไฟล์ใหม่จะเพิ่มตัวเลขไปยังชื่อของมัน",
     "Cancel" : "ยกเลิก",
     "Continue" : "ดำเนินการต่อ",
     "(all selected)" : "(เลือกทั้งหมด)",
     "({count} selected)" : "(เลือกจำนวน {count})",
-    "Error loading file exists template" : "เกิดข้อผิดพลาดขณะโหลดไฟล์แม่แบบที่มีอยู่",
+    "Error loading file exists template" : "เกิดข้อผิดพลาดขณะโหลดไฟล์เทมเพลตที่มีอยู่",
     "Very weak password" : "รหัสผ่านระดับต่ำมาก",
     "Weak password" : "รหัสผ่านระดับต่ำ",
     "So-so password" : "รหัสผ่านระดับปกติ",
     "Good password" : "รหัสผ่านระดับดี",
     "Strong password" : "รหัสผ่านระดับดีมาก",
     "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "เว็บเซิร์ฟเวอร์ของคุณยังไม่ถูกติดตั้งอย่างถูกต้องเพื่ออนุญาตให้ประสานข้อมูลให้ตรงกัน เนื่องจากอินเตอร์เฟซ WebDAV อาจเสียหาย",
-    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "เว็บเซิร์ฟเวอร์ของคุณไม่ได้ติดตั้งอย่างถูกต้องเพื่อที่จะแก้ไข \"{url}\" สามารถข้อมูลเพิ่มเติมได้ใน <a target=\"_blank\" href=\"{docLink}\">เอกสาร</a> ของเรา",
-    "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "เซิร์ฟเวอร์นี้ไม่มีการเชื่อมต่ออินเทอร์เน็ตซึ่งหมายความว่าบางส่วนของคุณสมบัติ เช่น การจัดเก็บข้อมูลภายนอก การแจ้งเตือนเกี่ยวกับการปรับปรุงหรือการติดตั้งแอพพลิเคชันของบุคคลที่สามจะไม่ทำงาน การเข้าถึงไฟล์จากระยะไกลและการส่งอีเมล์แจ้งเตือนอาจจะไม่ทำงาน เราขอแนะนำให้เปิดใช้งานการเชื่อมต่ออินเทอร์เน็ตสำหรับเซิร์ฟเวอร์นี้ถ้าคุณต้องการใช้งานคุณสมบัติทั้งหมด",
-    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "ไม่ได้กำหนดค่าหน่วยความจำแคช เพื่อเพิ่มประสิทธิภาพของคุณโปรดกำหนดค่า memcache หากต้องการข้อมูลเพิ่มเติมสามารถอ่านได้ใน <a target=\"_blank\" href=\"{docLink}\">เอกสาร</a> ของเรา",
-    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "ไม่สามารถอ่าน /dev/urandom โดย PHP ซึ่งมีผลอย่างมากสำหรับเหตุผลด้านความปลอดภัย สามารถข้อมูลเพิ่มเติมได้ใน <a target=\"_blank\" href=\"{docLink}\">เอกสาร</a> ของเรา",
-    "Your PHP version ({version}) is no longer <a target=\"_blank\" href=\"{phpLink}\">supported by PHP</a>. We encourage you to upgrade your PHP version to take advantage of performance and security updates provided by PHP." : "PHP ของคุณรุ่น ({version}) <a target=\"_blank\" href=\"{phpLink}\">ไม่สนับสนุน PHP</a> เราขอแนะนำให้อัพเกรดรุ่น PHP ของคุณ เพื่อปรับปรุงประสิทธิภาพการทำงานและเนื้อหาด้านความปลอดภัย",
-    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "การกำหนดค่าส่วนหัวของรีเวิร์สพร็อกซี่ไม่ถูกต้องหรือคุณกำลังเข้าถึง ownCloud จากพร็อกซี่ที่เชื่อถือได้ ถ้าคุณไม่ได้เข้าถึง ownCloud จากพร็อกซี่ที่เชื่อถือได้นี้เป็นปัญหาด้านความปลอดภัยและมันจะอณุญาตทำให้แฮกเกอร์ปลอมที่อยู่ IP ของพวกเขา ข้อมูลเพิ่มเติมสามารถอ่านได้ใน <a target=\"_blank\" href=\"{docLink}\">เอกสาร</a> ของเรา",
-    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "การกำหนดค่า memcach ผิดพลาดเนื่องจากมีโมดูล PHP ของ memcache ได้ถูกติดตั้งไปแล้ว มีการติดตั้ง \\OC\\Memcache\\Memcached สนับสนุนเฉพาะ \"memcached\" แต่ไม่สนับสนุน \"memcache\" คุณสามารถดู <a target=\"_blank\" href=\"{wikiLink}\">ข้อมูลเกี่ยวกับทั้ง 2 โมดูล</a>",
-    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "บางไฟล์ยังไม่ผ่านการตรวจสอบความสมบูรณ์ ข้อมูลเพิ่มเติมเกี่ยวกับวิธีการแก้ไขปัญหาเหล่านี้สามารถอ่านได้จาก <a target=\"_blank\" href=\"{docLink}\">เอกสาร</a> ของเรา (<a href=\"{codeIntegrityDownloadEndpoint}\">รายชื่อของไฟล์ที่ไม่ถูกต้อง…</a> / <a href=\"{rescanEndpoint}\">ค้นหาใหม่…</a>)",
+    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "คุณตั้งค่าเว็บเซิร์ฟเวอร์ไม่ถูกต้องเพื่อแก้ไข \"{url}\" สำหรับข้อมูลเพิ่มเติมสามารถดูได้จาก <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">เอกสาร</a>",
+    "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "เซิร์ฟเวอร์นี้ไม่มีการเชื่อมต่ออินเทอร์เน็ตซึ่งหมายความว่าบางส่วนของคุณสมบัติ เช่น การจัดเก็บข้อมูลภายนอก การแจ้งเตือนเกี่ยวกับการอัพเดทหรือการติดตั้งแอพพลิเคชันของบุคคลที่สามจะไม่ทำงาน การเข้าถึงไฟล์จากระยะไกลและการส่งอีเมลแจ้งเตือนอาจจะไม่ทำงาน เราขอแนะนำให้เปิดใช้งานการเชื่อมต่ออินเทอร์เน็ตสำหรับเซิร์ฟเวอร์นี้ถ้าคุณต้องการใช้งานคุณสมบัติทั้งหมด",
+    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "ไม่ได้กำหนดค่าหน่วยความจำแคช เพื่อเพิ่มประสิทธิภาพของคุณโปรดกำหนดค่า memcache หากคุณมี สำหรับข้อมูลเพิ่มเติมสามารถดูได้จาก\n<a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">เอกสาร</a>",
+    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "/dev/urandom ไม่สามารถอ่านโดย PHP นี่เป็นสิ่งสำคัญสำหรับเรื่องความปลอดภัย สำหรับข้อมูลเพิ่มเติมสามารถดูได้จาก <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">เอกสาร</a>",
+    "You are currently running PHP {version}. We encourage you to upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "ขณะนี้คุณกำลังใช้ PHP รุ่น {version} เราขอให้คุณอัพเดท <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">เพื่อเหตุผลด้านประสิทธิภาพและความปลอดภัยของ PHP</a> ทันทีที่ระบบของคุณได้รับการสนับสนุน",
+    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "กำหนดค่าพร็อกซี่ส่วนหัวไม่ถูกต้องหรือคุณเข้าถึง ownCloud จากพร็อกซี่ที่ไม่น่าเชื่อถือ นี้เป็นปัญหาด้านความปลอดภัยและสามารถทำให้ผู้โจมตีปลอมที่อยู่ IP ownCloud ของคุณ สำหรับข้อมูลเพิ่มเติมสามารถดูได้จาก <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">เอกสาร</a>",
+    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "ได้มีการกำหนดค่าการกระจาย Memcached แต่โมดูล PHP ผิด \"memcache\" ได้ถูกติดตั้งแล้ว \\OC\\Memcache\\Memcached สนับสนุนเฉพาะ \"memcached\" แต่ไม่ใช่ \"memcache\" สำหรับข้อมูลเพิ่มเติมสามารถดูได้จาก <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">วิกิพีเดีย memcached เกี่ยวกับทั้งสองโมดูล</a>",
+    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "บางไฟล์ยังไม่ได้ผ่านการตรวจสอบความสมบูรณ์ สำหรับข้อมูลเพิ่มเติมสามารถดูได้จาก <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">เอกสาร</a> (<a href=\"{codeIntegrityDownloadEndpoint}\">รายการของไฟล์ที่ไม่ถูกต้อง…</a> / <a href=\"{rescanEndpoint}\">สแกนใหม่…</a>)",
     "Error occurred while checking server setup" : "เกิดข้อผิดพลาดขณะที่ทำการตรวจสอบการติดตั้งเซิร์ฟเวอร์",
     "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "ข้อมูลไดเรกทอรีและไฟล์ของคุณอาจจะสามารถเข้าถึงได้จากอินเทอร์เน็ต ขณะที่ htaccess ไฟล์ไม่ทำงาน เราขอแนะนำให้คุณกำหนดค่าเว็บเซิร์ฟเวอร์ของคุณในทางที่ข้อมูลไดเรกทอรีไม่สามารถเข้าถึงได้หรือคุณย้ายข้อมูลไดเรกทอรีไปยังนอกเว็บเซิร์ฟเวอร์หรือเอกสาร",
-    "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "\"{header}\" ไม่ได้กำหนดค่าส่วนหัว Http ให้เท่ากับ \"{expected}\" นี่คือระบบการรักษาความปลอดภัยที่มีศักยภาพหรือลดความเสี่ยงที่จะเกิดขึ้นเราขอแนะนำให้ปรับการตั้งค่านี้",
-    "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "คุณกำลังเข้าถึงเว็บไซต์นี้ผ่านทาง HTTP เราขอแนะนำให้คุณกำหนดค่าเซิร์ฟเวอร์ของคุณที่จะต้องใช้ HTTPS แทนตามที่อธิบายไว้ใน <a href=\"{docUrl}\">เคล็ดลับการรักษาความปลอดภัย</a> ของเรา",
+    "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "\"{header}\" ไม่ได้กำหนดค่าส่วนหัว HTTP ให้เท่ากับ \"{expected}\" นี่คือระบบการรักษาความปลอดภัยที่มีศักยภาพหรือลดความเสี่ยงที่จะเกิดขึ้นเราขอแนะนำให้ปรับการตั้งค่านี้",
+    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\" rel=\"noreferrer\">security tips</a>." : "\"Strict-Transport-Security\" HTTP ส่วนหัวไม่ได้กำหนดค่าให้มีอย่างน้อย \"{seconds}\" วินาที เพื่อความปลอดภัยเราขอแนะนำให้เปิด HSTS สามารถอ่านได้จาก <a href=\"{docUrl}\" rel=\"noreferrer\">เคล็ดลับความปลอดภัย</a>",
+    "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "คุณกำลังเข้าถึงเว็บไซต์นี้ผ่านช่องทาง HTTP เราขอแนะนำให้คุณใช้ HTTPS แทนตามที่อธิบายไว้ใน <a href=\"{docUrl}\">เคล็ดลับการรักษาความปลอดภัย</a> ของเรา",
     "Shared" : "แชร์แล้ว",
     "Shared with {recipients}" : "แชร์กับ {recipients}",
     "Error" : "ข้อผิดพลาด",
     "Error while sharing" : "เกิดข้อผิดพลาดขณะกำลังแชร์ข้อมูล",
     "Error while unsharing" : "เกิดข้อผิดพลาดขณะกำลังยกเลิกการแชร์ข้อมูล",
-    "Error setting expiration date" : "เกิดข้อผิดพลาดในการตั้งค่าวันที่หมดอายุ",
     "The public link will expire no later than {days} days after it is created" : "ลิงค์สาธารณะจะหมดอายุภายใน {days} วัน หลังจากที่มันถูกสร้างขึ้น",
     "Set expiration date" : "กำหนดวันที่หมดอายุ",
     "Expiration" : "การหมดอายุ",
     "Expiration date" : "วันที่หมดอายุ",
-    "Choose a password for the public link" : "เลือกรหัสผ่านสำหรับลิงค์สาธารณะ",
-    "Sending ..." : "กำลังส่ง...",
-    "Email sent" : "ส่งอีเมล์แล้ว",
-    "Resharing is not allowed" : "ไม่อนุญาตให้แชร์ข้อมูลที่ซ้ำกัน",
-    "Share link" : "แชร์ลิงค์",
+    "Expiration date is required" : "ต้องระบุวันหมดอายุ",
+    "Delete {link}" : "ลบ {link}",
+    "Remove link" : "ลบลิงค์",
+    "{fileName} link" : "ลิงค์ {fileName}",
     "Link" : "ลิงค์",
-    "Password protect" : "รหัสผ่านป้องกัน",
+    "Create public link" : "สร้างลิงก์สาธารณะ",
+    "Edit" : "แก้ไข",
+    "Remove" : "ลบออก",
+    "Click to copy to clipboard" : "คลิกเพื่อคัดลอกไปยังคลิปบอร์ด",
+    "Social share" : "แชร์ไปยังเครือข่ายทางสังคม",
+    "There are currently no link shares, you can create one" : "ขณะนี้ยังไม่มีการแชร์ลิงก์ใดๆ",
+    "Anyone with the link has access to the file/folder" : "ทุกคนที่มีลิงก์สามารถเข้าถึงไฟล์หรือโฟลเดอร์ได้",
+    "Copied!" : "คัดลอกแล้ว!",
+    "Not supported!" : "ไม่ได้รับการสนับสนุน!",
+    "Press ⌘-C to copy." : "กดปุ่ม ⌘-C เพื่อคัดลอก",
+    "Press Ctrl-C to copy." : "กดปุ่ม Ctrl-C เพื่อคัดลอก",
+    "Choose a password for the public link" : "เลือกรหัสผ่านสำหรับลิงค์สาธารณะ",
+    "Password required" : "จะต้องระบุรหัสผ่าน",
+    "Filename" : "ชื่อไฟล์",
     "Password" : "รหัสผ่าน",
+    "Name" : "ชื่อ",
     "Allow editing" : "อนุญาตให้แก้ไข",
+    "Show file listing" : "แสดงรายชื่อไฟล์",
+    "Edit link share: {name}" : "แก้ไขลิงค์ที่แชร์: {name}",
+    "Save" : "บันทึก",
+    "Create link share: {name}" : "สร้างแชร์ลิงค์: {name}",
+    "Remove password" : "ลบรหัสผ่าน",
+    "Share to Twitter. Opens in a new window." : "แชร์ไปยัง Twitter เปิดในหน้าต่างใหม่",
+    "Share to Facebook. Opens in a new window." : "แชร์ไปยัง Facebook เปิดในหน้าต่างใหม่",
+    "Share to Diaspora. Opens in a new window." : "แชร์ไปยัง Diaspora เปิดในหน้าต่างใหม่",
+    "Share to Google+. Opens in a new window." : "แชร์ไปยัง Google+ เปิดในหน้าต่างใหม่",
+    "Share via email. Opens your mail client." : "แชร์ผ่านอีเมล เปิดไคลเอ็นต์อีเมลของคุณ",
+    "Error while sending notification" : "เกิดข้อผิดพลาดขณะกำลังส่งการแจ้งเตือน",
+    "Sending ..." : "กำลังส่ง...",
+    "Email sent" : "ส่งอีเมลแล้ว",
     "Email link to person" : "ส่งลิงก์ให้ทางอีเมล",
-    "Send" : "ส่ง",
+    "Send link via email" : "ส่งลิงก์ผ่านทางอีเมล",
     "Shared with you and the group {group} by {owner}" : "ได้แชร์ให้กับคุณ และกลุ่ม {group} โดย {owner}",
     "Shared with you by {owner}" : "ถูกแชร์ให้กับคุณโดย {owner}",
     "group" : "กลุ่มผู้ใช้งาน",
-    "remote" : "ระยะไกล",
+    "remote" : "รีโมท",
     "notify by email" : "แจ้งเตือนทางอีเมล",
     "Unshare" : "ยกเลิกการแชร์",
     "can share" : "สามารถแชร์ได้",
@@ -166,37 +195,49 @@ OC.L10N.register(
     "access control" : "ควบคุมการเข้าถึง",
     "Could not unshare" : "ไม่สามารถยกเลิกการแชร์ได้",
     "Share details could not be loaded for this item." : "รายละเอียดการแชร์ไม่สามารถโหลดสำหรับรายการนี้",
-    "An error occured. Please try again" : "เกิดข้อผิดพลาด กรุณาลองอีกครั้ง",
+    "No users or groups found for {search}" : "ไม่พบผู้ใช้หรือกลุ่มที่มีชื่อว่า {search}",
+    "No users found for {search}" : "ไม่พบผู้ใช้ {search}",
+    "An error occurred. Please try again" : "มีข้อผิดพลาดเกิดขึ้นโปรดลองอีกครั้ง",
+    "{sharee} (group)" : "{sharee} (กลุ่ม)",
+    "{sharee} (at {server})" : "{sharee} (ที่ {server})",
+    "{sharee} (remote)" : "{sharee} (รีโมท)",
     "Share" : "แชร์",
+    "User and Groups" : "ผู้ใช้และกลุ่ม",
+    "Public Links" : "ลิงก์สาธารณะ",
+    "Resharing is not allowed" : "ไม่อนุญาตให้แชร์ข้อมูลที่ซ้ำกัน",
     "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "แชร์กับคนใน ownClouds อื่นๆ ที่ใช้ไวยากรณ์ username@example.com/owncloud ",
-    "Share with users or groups …" : "แชร์กับผู้ใช้หรือกลุ่ม ...",
-    "Share with users, groups or remote users …" : "แชร์กับผู้ใช้กลุ่มหรือผู้ใช้ระยะไกล ...",
+    "Share with users…" : "แชร์กับผู้ใช้ ...",
+    "Share with users, groups or remote users…" : "แชร์กับผู้ใช้หรือกลุ่มหรือผู้ใช้โดยการรีโมท ...",
+    "Share with users or groups…" : "แชร์กับผู้ใช้หรือกลุ่ม ...",
+    "Share with users or remote users…" : "แชร์กับผู้ใช้หรือผู้ใช้โดยการรีโมท ...",
     "Error removing share" : "พบข้อผิดพลาดในรายการที่แชร์ออก",
     "Warning" : "คำเตือน",
-    "Error while sending notification" : "เกิดข้อผิดพลาดขณะกำลังส่งการแจ้งเตือน",
     "Non-existing tag #{tag}" : "ไม่มีแท็กนี้อยู่ #{tag}",
-    "not assignable" : "ไม่ได้รับมอบหมาย",
+    "restricted" : "ถูกจำกัด",
     "invisible" : "จะมองไม่เห็น",
     "({scope})" : "({scope})",
     "Delete" : "ลบ",
     "Rename" : "เปลี่ยนชื่อ",
+    "Collaborative tags" : "แท็กที่ทำงานร่วมกัน",
     "The object type is not specified." : "ชนิดของวัตถุยังไม่ได้รับการระบุ",
     "Enter new" : "ใส่ข้อมูลใหม่",
     "Add" : "เพิ่ม",
     "Edit tags" : "แก้ไขแท็ก",
-    "Error loading dialog template: {error}" : "เกิดข้อผิดพลาดขณะโหลดไดอะล็อกแม่แบบ: {error}",
+    "Error loading dialog template: {error}" : "เกิดข้อผิดพลาดขณะโหลดเทมเพลตไดอะล็อก: {error}",
     "No tags selected for deletion." : "ไม่ได้เลือกแท็กที่ต้องการลบ",
     "unknown text" : "ข้อความที่ไม่รู้จัก",
     "Hello world!" : "สวัสดีทุกคน!",
     "sunny" : "แดดมาก",
     "Hello {name}, the weather is {weather}" : "สวัสดี {name} สภาพอากาศวันนี้มี {weather}",
     "Hello {name}" : "สวัสดี {name}",
+    "new" : "ใหม่",
     "_download %n file_::_download %n files_" : ["ดาวน์โหลด %n ไฟล์"],
     "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "กำลังดำเนินการอัพเกรด หากออกจากหน้านี้ ณ เวลานี้อาจเกิดปัญหาในภายหลัง",
-    "Updating {productName} to version {version}, this may take a while." : "กำลังอัพเดท {productName} ไปยังรุ่น {version} อาจใช้เวลาสักครู่",
+    "Updating to {version}" : "กำลังอัพเดทเป็นรุ่น {version}",
     "An error occurred." : "เกิดข้อผิดพลาด",
     "Please reload the page." : "โปรดโหลดหน้าเว็บใหม่",
-    "The update was unsuccessful. " : "อัพเดทไม่สำเร็จ",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "อัพเดทไม่สำเร็จ สำหรับข้อมูลเพิ่มเติมหาอ่านได้จาก <a href=\"{url}\">ตรวจสอบโพสต์ในฟอรั่มของเรา</a> เพื่อแก้ไขปัญหานี้",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "การอัพเดทไม่เป็นผลสำเร็จ กรุณาแจ้งปัญหาที่เกิดขึ้นไปยัง <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">คอมมูนิตี้ผู้ใช้งาน ownCloud</a>",
     "The update was successful. There were warnings." : "การอัพเดทสำเร็จ แต่มีคำเตือนอยู่",
     "The update was successful. Redirecting you to ownCloud now." : "การอัพเดทเสร็จเรียบร้อย กำลังเปลี่ยนเส้นทางไปที่ ownCloud อยู่ในขณะนี้",
     "Searching other places" : "กำลังค้นหาสถานที่อื่นๆ",
@@ -204,16 +245,9 @@ OC.L10N.register(
     "_{count} search result in another folder_::_{count} search results in other folders_" : ["ค้นหาพบ {count} ผลลัพธ์ในโฟลเดอร์อื่นๆ"],
     "Personal" : "ส่วนตัว",
     "Users" : "ผู้ใช้งาน",
-    "Apps" : "แอปฯ",
+    "Apps" : "แอพฯ",
     "Admin" : "ผู้ดูแล",
     "Help" : "ช่วยเหลือ",
-    "Error loading tags" : "เกิดข้อผิดพลาดขณะโหลดแท็ก",
-    "Tag already exists" : "มีแท็กอยู่แล้ว",
-    "Error deleting tag(s)" : "เกิดข้อผิดพลาดขณะลบแท็ก",
-    "Error tagging" : "เกิดข้อผิดพลาดขณะติดแท็ก",
-    "Error untagging" : "เกิดข้อผิดพลาดขณะยกเลิกการติดแท็ก",
-    "Error favoriting" : "เกิดข้อผิดพลาดขณะเลือกที่ชื่นชอบ",
-    "Error unfavoriting" : "เกิดข้อผิดพลาดขณะยกเลิกการเลือกที่ชื่นชอบ",
     "Access forbidden" : "การเข้าถึงถูกหวงห้าม",
     "File not found" : "ไม่พบไฟล์",
     "The specified document has not been found on the server." : "ไม่พบเอกสารที่ระบุบนเซิร์ฟเวอร์",
@@ -224,9 +258,9 @@ OC.L10N.register(
     "Internal Server Error" : "เกิดข้อผิดพลาดภายในเซิร์ฟเวอร์",
     "The server encountered an internal error and was unable to complete your request." : "พบข้อผิดพลาดภายในเซิร์ฟเวอร์และไม่สามารถดำเนินการตามคำขอของคุณ",
     "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "กรุณาติดต่อผู้ดูแลเซิร์ฟเวอร์ถ้าพบข้อผิดพลาดนี้หลายครั้ง กรุณาระบุรายละเอียดทางเทคนิคที่ด้านล่างในรายงานของคุณ",
-    "More details can be found in the server log." : "รายละเอียดเพิ่มเติมสามารถดูได้ที่บันทึกของระบบเซิร์ฟเวอร์",
+    "More details can be found in the server log." : "รายละเอียดเพิ่มเติมสามารถดูได้ในไฟล์ log ของเซิร์ฟเวอร์",
     "Technical details" : "รายละเอียดทางเทคนิค",
-    "Remote Address: %s" : "ที่อยู่รีโมทระยะไกล: %s",
+    "Remote Address: %s" : "ที่อยู่รีโมท: %s",
     "Request ID: %s" : "คำขอ ID: %s",
     "Type: %s" : "ชนิด: %s",
     "Code: %s" : "โค้ด: %s",
@@ -234,9 +268,6 @@ OC.L10N.register(
     "File: %s" : "ไฟล์: %s",
     "Line: %s" : "ไลน์: %s",
     "Trace" : "ร่องรอย",
-    "Security warning" : "คำเตือนการรักษาความปลอดภัย",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "ข้อมูลไดเรกทอรีและไฟล์ของคุณ อาจไม่สามารถเข้าถึงได้จากอินเทอร์เน็ตเพราะ htaccess ไฟล์ไม่ทำงาน",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "สำหรับข้อมูลวิธีการกำหนดค่าเซิร์ฟเวอร์ของคุณดูได้ที่ <a href=\"%s\" target=\"_blank\">เอกสาร</a>",
     "Create an <strong>admin account</strong>" : "สร้าง <strong>บัญชีผู้ดูแลระบบ</strong>",
     "Username" : "ชื่อผู้ใช้งาน",
     "Storage & database" : "พื้นที่จัดเก็บข้อมูลและฐานข้อมูล",
@@ -244,41 +275,49 @@ OC.L10N.register(
     "Configure the database" : "ตั้งค่าฐานข้อมูล",
     "Only %s is available." : "เฉพาะ %s สามารถใช้ได้",
     "Install and activate additional PHP modules to choose other database types." : "ติดตั้งและเปิดใช้งานโมดูล PHP เพิ่มเติมเพื่อเลือกชนิดฐานข้อมูลอื่นๆ",
-    "For more details check out the documentation." : "สำหรับรายละเอียดเพิ่มเติมสามารถตรวจสอบได้ที่ <a href=\"%s\" target=\"_blank\">เอกสาร</a>",
+    "For more details check out the documentation." : "สำหรับรายละเอียดเพิ่มเติมสามารถดูได้ที่ <a href=\"%s\" target=\"_blank\">เอกสาร</a>",
     "Database user" : "ชื่อผู้ใช้งานฐานข้อมูล",
     "Database password" : "รหัสผ่านฐานข้อมูล",
     "Database name" : "ชื่อฐานข้อมูล",
     "Database tablespace" : "พื้นที่ตารางในฐานข้อมูล",
     "Database host" : "Database host",
-    "Performance warning" : "การเตือนประสิทธิภาพการทำงาน",
+    "Please specify the port number along with the host name (e.g., localhost: 5432)." : "กรุณาระบุชื่อโฮสต์และหมายเลขพอร์ต (ตัวอย่าง localhost:5432)",
+    "Performance warning" : "คำเตือนเรื่องประสิทธิภาพการทำงาน",
     "SQLite will be used as database." : "SQLite จะถูกใช้เป็นฐานข้อมูล",
     "For larger installations we recommend to choose a different database backend." : "สำหรับการติดตั้งขนาดใหญ่เราขอแนะนำให้เลือกแบ็กเอนด์ฐานข้อมูลที่แตกต่างกัน",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "โดยเฉพาะอย่างยิ่งเมื่อใช้ไคลเอนต์เดสก์ทอปสำหรับการประสานข้อมูลโดย SQLite",
-    "Finish setup" : "ติดตั้งเรียบร้อยแล้ว",
+    "Finish setup" : "ติดตั้งเลย",
     "Finishing …" : "เสร็จสิ้น ...",
     "Need help?" : "ต้องการความช่วยเหลือ?",
-    "See the documentation" : "ดูที่เอกสาร",
+    "See the documentation" : "ดูได้จากเอกสาร",
     "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "นี่คุณ,<br><br>อยากให้คุณทราบว่า %s ได้แชร์ <strong>%s</strong> กับคุณ <br><a href=\"%s\">คลิกดูที่นี่</a><br><br>",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "โปรแกรมนี้ต้องการ JavaScript สำหรับการดำเนินงานที่ถูกต้อง กรุณา {linkstart}เปิดใช้งาน JavaScript{linkend} และโหลดหน้าเว็บ",
     "Log out" : "ออกจากระบบ",
     "Search" : "ค้นหา",
     "Server side authentication failed!" : "การรับรองความถูกต้องจากเซิร์ฟเวอร์ล้มเหลว!",
     "Please contact your administrator." : "กรุณาติดต่อผู้ดูแลระบบ",
-    "An internal error occured." : "เกิดข้อผิดพลาดภายใน",
+    "An internal error occurred." : "มีข้อผิดพลาดภายในเกิดขึ้น",
     "Please try again or contact your administrator." : "โปรดลองอีกครั้งหรือติดต่อผู้ดูแลระบบ",
+    "Username or email" : "ชื่อผู้ใช้หรืออีเมล",
     "Log in" : "เข้าสู่ระบบ",
-    "Wrong password. Reset it?" : "รหัสผ่านผิด ตั้งค่าใหม่?",
+    "Wrong password. Reset it?" : "รหัสผ่านผิด รีเซ็ตรหัสผ่าน?",
     "Wrong password." : "รหัสผ่านผิดพลาด",
-    "Stay logged in" : "กำลังอยู่ในระบบ",
+    "Stay logged in" : "จดจำฉัน",
     "Alternative Logins" : "ทางเลือกการเข้าสู่ระบบ",
-    "Use the following link to reset your password: {link}" : "ใช้ลิงค์ต่อไปนี้เพื่อเปลี่ยนรหัสผ่านของคุณใหม่: {link}",
+    "Use the following link to reset your password: {link}" : "ใช้ลิงค์ต่อไปนี้เพื่อเปลี่ยนรหัสผ่านใหม่ของคุณ: {link}",
+    "Password changed successfully" : "เปลี่ยนรหัสผ่านเรียบร้อยแล้ว",
     "New password" : "รหัสผ่านใหม่",
     "New Password" : "รหัสผ่านใหม่",
     "Reset password" : "เปลี่ยนรหัสผ่านใหม่",
     "This ownCloud instance is currently in single user mode." : "ขณะนี้ ownCloud อยู่ในโหมดผู้ใช้คนเดียว",
     "This means only administrators can use the instance." : "ซึ่งหมายความว่าผู้ดูแลระบบสามารถใช้อินสแตนซ์",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "ติดต่อผู้ดูแลระบบของคุณหากข้อความนี้ยังคงมีอยู่หรือปรากฏโดยไม่คาดคิด",
-    "Thank you for your patience." : "ขอบคุณสำหรับความอดทนของคุณ เราจะนำความคิดเห็นของท่านมาปรับปรุงระบบให้ดียิ่งขึ้น",
+    "Thank you for your patience." : "ขอบคุณสำหรับความคิดเห็น เราจะนำความคิดเห็นของท่านมาอัพเดทระบบให้ดียิ่งขึ้น",
+    "Two-step verification" : "การยืนยันแบบสองขั้นตอน",
+    "Enhanced security has been enabled for your account. Please authenticate using a second factor." : "ความปลอดภัยขั้นสูงได้ถูกเปิดใช้งานกับบัญชีของคุณ กรุณาตรวจสอบการรับรองความถูกต้องขั้นตอนที่สอง",
+    "Cancel login" : "ยกเลิกการเข้าสู่ระบบ",
+    "Please authenticate using the selected factor." : "กรุณาตรวจสอบโดยเลือกปัจจัยอื่นๆ",
+    "An error occurred while verifying the token" : "เกิดข้อผิดพลาดขณะทำการตรวจสอบโทเค็น",
     "You are accessing the server from an untrusted domain." : "คุณกำลังเข้าถึงเซิร์ฟเวอร์จากโดเมนที่ไม่น่าเชื่อถือ",
     "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "กรุณาติดต่อผู้ดูแลระบบ หากคุณเป็นผู้ดูแลระบบ นี้ตัวอย่างการกำหนดค่า \"trusted_domains\" ใน\nconfig/config.php ตัวอย่างการกำหนดค่ามีอยู่ใน config/config.sample.php",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "ทั้งนี้ขึ้นอยู่กับการกำหนดค่าของคุณ ผู้ดูแลระบบอาจสามารถใช้ปุ่มด้านล่างเพื่อกำหนดให้โดเมนนี้มีความน่าเชื่อถือ",
@@ -286,14 +325,15 @@ OC.L10N.register(
     "App update required" : "จำเป้นต้องอัพเดทแอพฯ",
     "%s will be updated to version %s" : "%s จะถูกอัพเดทเป็นเวอร์ชัน %s",
     "These apps will be updated:" : "แอพพลิเคชันเหล่านี้จะถูกอัพเดท:",
-    "These incompatible apps will be disabled:" : "แอพพลิเคชันเหล่านี้เข้ากันไม่ได้จะถูกปิดการใช้งาน:",
     "The theme %s has been disabled." : "ธีม %s จะถูกปิดการใช้งาน:",
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "โปรดตรวจสอบฐานข้อมูล การตั้งค่าโฟลเดอร์และโฟลเดอร์ข้อมูลจะถูกสำรองไว้ก่อนดำเนินการ",
     "Start update" : "เริ่มต้นอัพเดท",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "เพื่อหลีกเลี่ยงการหมดเวลากับการติดตั้งขนาดใหญ่ คุณสามารถเรียกใช้คำสั่งต่อไปนี้จากไดเรกทอรีการติดตั้งของคุณ:",
+    "Detailed logs" : "รายละเอียดการบันทึก",
+    "Update needed" : "การปรับปรุงที่จำเป็น",
+    "Please use the command line updater because you have a big instance." : "กรุณาใช้คำสั่งการอัพเดทเพราะเหตุผลบางอย่าง",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : " สำหรับข้อมูลเพิ่มเติมสามารถดูได้จาก <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">เอกสาร</a>",
     "This %s instance is currently in maintenance mode, which may take a while." : "%s กำลังอยู่ในโหมดการบำรุงรักษาซึ่งอาจใช้เวลาสักครู่",
-    "This page will refresh itself when the %s instance is available again." : "หน้านี้จะรีเฟรชตัวเองเมื่อ %s สามารถใช้ได้อีกครั้ง",
-    "Error loading file picker template: {error}" : "เกิดข้อผิดพลาดขณะกำลังโหลดไฟล์แม่แบบ: {error}",
-    "Password can not be changed. Please contact your administrator." : "หากคุณไม่สามารถเปลี่ยนแปลงรหัสผ่าน กรุณาติดต่อผู้ดูแลระบบ"
+    "This page will refresh itself when the %s instance is available again." : "หน้านี้จะรีเฟรชตัวเองเมื่อ %s สามารถใช้ได้อีกครั้ง"
 },
 "nplurals=1; plural=0;");
