@@ -16,12 +16,6 @@ OC.L10N.register(
     "Library %s with a version lower than %s is required - available version %s." : "%s liburutegiak %s baino bertsio txikiagoa izan behar du - dagoen bertsioa %s.",
     "Following platforms are supported: %s" : "Hurrengo plataformak onartzen dira: %s",
     "ownCloud %s or higher is required." : "ownCloud %s edo haundiagoa behar da.",
-    "Help" : "Laguntza",
-    "Personal" : "Pertsonala",
-    "Users" : "Erabiltzaileak",
-    "Admin" : "Admin",
-    "Recommended" : "Aholkatuta",
-    "No app name specified" : "Ez da aplikazioaren izena zehaztu",
     "Unknown filetype" : "Fitxategi mota ezezaguna",
     "Invalid image" : "Baliogabeko irudia",
     "today" : "gaur",
@@ -34,7 +28,9 @@ OC.L10N.register(
     "_%n hour ago_::_%n hours ago_" : ["orain dela ordu %n","orain dela %n ordu"],
     "_%n minute ago_::_%n minutes ago_" : ["orain dela minutu %n","orain dela %n minutu"],
     "seconds ago" : "segundu",
-    "web services under your control" : "web zerbitzuak zure kontrolpean",
+    "None" : "Ezer",
+    "Username" : "Erabiltzaile izena",
+    "Password" : "Pasahitza",
     "File name contains at least one invalid character" : "Fitxategi izenak behintzat baliogabeko karaktere bat du",
     "App directory already exists" : "Aplikazioaren karpeta dagoeneko existitzen da",
     "Can't create app folder. Please fix permissions. %s" : "Ezin izan da aplikazioaren karpeta sortu. Mesdez konpondu baimenak. %s",
@@ -47,10 +43,14 @@ OC.L10N.register(
     "App can't be installed because of not allowed code in the App" : "Aplikazioa ezin da instalatu bertan duen baimendu gabeko kodea dela eta",
     "App can't be installed because it is not compatible with this version of ownCloud" : "Aplikazioa ezin da instalatu ownCloud bertsio honekin bateragarria ez delako",
     "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Aplikazioa ezin da instalatu <shipped>true</shipped> etiketa duelako eta etiketa hau ez da onartzen banaketan ez datozen aplikazioetan",
-    "Application is not enabled" : "Aplikazioa ez dago gaituta",
-    "Authentication error" : "Autentifikazio errorea",
-    "Token expired. Please reload page." : "Tokena iraungitu da. Mesedez birkargatu orria.",
-    "Unknown user" : "Erabiltzaile ezezaguna",
+    "Apps" : "Aplikazioak",
+    "General" : "Orokorra",
+    "Storage" : "Biltegiratzea",
+    "Security" : "Segurtasuna",
+    "Encryption" : "Enkriptazioa",
+    "Sharing" : "Partekatzea",
+    "Search" : "Bilatu",
+    "Updates" : "Eguneraketak",
     "%s enter the database username." : "%s sartu datu basearen erabiltzaile izena.",
     "%s enter the database name." : "%s sartu datu basearen izena.",
     "%s you may not use dots in the database name" : "%s ezin duzu punturik erabili datu basearen izenean.",
@@ -92,16 +92,21 @@ OC.L10N.register(
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "%s elkarbanatzeak huts egin du, %sren elkarbanaketa motorrak bere iturria aurkitu ezin duelako",
     "Sharing %s failed, because the file could not be found in the file cache" : "%s elkarbanatzeak huts egin du, fitxategia katxean aurkitu ez delako",
     "Could not find category \"%s\"" : "Ezin da \"%s\" kategoria aurkitu",
-    "Apps" : "Aplikazioak",
     "A valid username must be provided" : "Baliozko erabiltzaile izena eman behar da",
     "A valid password must be provided" : "Baliozko pasahitza eman behar da",
     "The username is already being used" : "Erabiltzaile izena dagoeneko erabiltzen ari da",
+    "Help" : "Laguntza",
+    "Settings" : "Ezarpenak",
+    "Users" : "Erabiltzaileak",
+    "web services under your control" : "web zerbitzuak zure kontrolpean",
+    "Application is not enabled" : "Aplikazioa ez dago gaituta",
+    "Authentication error" : "Autentifikazio errorea",
+    "Token expired. Please reload page." : "Tokena iraungitu da. Mesedez birkargatu orria.",
+    "Unknown user" : "Erabiltzaile ezezaguna",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Ez dago datubaseen (sqlite, mysql edo postgresql) driverrik instalatuta.",
     "Cannot write into \"config\" directory" : "Ezin da idatzi \"config\" karpetan",
     "Cannot write into \"apps\" directory" : "Ezin da idatzi \"apps\" karpetan",
     "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Hau normalean konpondu daiteke %sweb zerbitzarira apps karpetan idazteko baimenak emanez%s edo konfigurazio fitxategian appstorea ez gaituz.",
-    "Cannot create \"data\" directory (%s)" : "Ezin da \"data\" karpeta sortu (%s)",
-    "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "Hau normalean konpondu daiteke  <a href=\"%s\" target=\"_blank\">web zerbitzarira erro karpetan idazteko baimenak emanez</a>.",
     "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Hau normalean konpondu daiteke %sweb zerbitzarira erro karpetan idazteko baimenak emanez%s.",
     "Setting locale to %s failed" : "Lokala %sra ezartzeak huts egin du",
     "Please install one of these locales on your system and restart your webserver." : "Instalatu hauetako lokal bat zure sisteman eta berrabiarazi zure web zerbitzaria.",
@@ -113,10 +118,7 @@ OC.L10N.register(
     "PostgreSQL >= 9 required" : "PostgreSQL >= 9 behar da",
     "Please upgrade your database version" : "Mesedez eguneratu zure datu basearen bertsioa",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Mesedez aldatu baimenak 0770ra beste erabiltzaileek karpetan sartu ezin izateko.",
-    "Data directory (%s) is readable by other users" : "Data karpeta (%s) beste erabiltzaileek irakur dezakete",
-    "Data directory (%s) is invalid" : "Datuen karpeta (%s) ez da baliogarria",
     "Please check that the data directory contains a file \".ocdata\" in its root." : "Mesedez egiaztatu data karpeta \".ocdata\" fitxategia duela bere erroan.",
-    "Could not obtain lock type %d on \"%s\"." : "Ezin da lortu sarraia mota %d \"%s\"-an.",
-    "Storage not available" : "Biltegia ez dago eskuragarri"
+    "Could not obtain lock type %d on \"%s\"." : "Ezin da lortu sarraia mota %d \"%s\"-an."
 },
 "nplurals=2; plural=(n != 1);");
