@@ -13,12 +13,6 @@ OC.L10N.register(
     "The library %s is not available." : "Knjiznica %s nije dostupna.",
     "Following platforms are supported: %s" : "Sljedece platforme su podrzane: %s",
     "ownCloud %s or higher is required." : "ownCloud %s ili visi je potreban.",
-    "Help" : "Pomoć",
-    "Personal" : "Osobno",
-    "Users" : "Korisnici",
-    "Admin" : "Admin",
-    "Recommended" : "Preporuceno",
-    "No app name specified" : "Nikakav naziv aplikacije nije naveden",
     "Unknown filetype" : "Vrsta datoteke nepoznata",
     "Invalid image" : "Neispravna slika",
     "today" : "Danas",
@@ -29,7 +23,9 @@ OC.L10N.register(
     "_%n hour ago_::_%n hours ago_" : ["prije %n sata","prije %n sati","prije %n sati"],
     "_%n minute ago_::_%n minutes ago_" : ["prije %n minute","prije %n minuta","prije %n minuta"],
     "seconds ago" : "prije par sekundi",
-    "web services under your control" : "web usluge pod vašom kontrolom",
+    "None" : "Ništa",
+    "Username" : "Korisničko ime",
+    "Password" : "Lozinka",
     "App directory already exists" : "Direktorij aplikacije već postoji",
     "Can't create app folder. Please fix permissions. %s" : "Nije moguće kreirati mapu aplikacija. molimo popravite dozvole. %s",
     "No source specified when installing app" : "Pri instaliranju aplikacija nijedan izvor nije specificiran",
@@ -41,11 +37,13 @@ OC.L10N.register(
     "App can't be installed because of not allowed code in the App" : "Aplikaciju nije moguće instalirati zbog nedopuštenog koda u njoj.",
     "App can't be installed because it is not compatible with this version of ownCloud" : "Aplikaciju nije moguće instalirati jer nije kompatibilna s ovom verzijom ownClouda.",
     "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Aplikaciju nije moguće instalirati jer sadrži oznaku <otpremljeno>istinito</otpremljeno>.",
-    "App can't be installed because the version in info.xml/version is not the same as the version reported from the app store" : "Aplikaciju nije moguće instalirati jer verzija u info.xml/version nije ista kaoverzija koju je prijavio app store",
-    "Application is not enabled" : "Aplikacija nije aktivirana",
-    "Authentication error" : "Pogrešna autentikacija",
-    "Token expired. Please reload page." : "Token je istekao. Molimo, ponovno učitajte stranicu.",
-    "Unknown user" : "Korisnik nepoznat",
+    "Apps" : "Aplikacije",
+    "General" : "Općenito",
+    "Security" : "Sigurnost",
+    "Encryption" : "Šifriranje",
+    "Sharing" : "Dijeljenje zajedničkih resursa",
+    "Search" : "pretraži",
+    "Updates" : "nadogradnje",
     "%s enter the database username." : "%s unesite naziva korisnika baze podataka.",
     "%s enter the database name." : "%s unesite naziv baze podataka",
     "%s you may not use dots in the database name" : "%s ne smijete koristiti točke u nazivu baze podataka",
@@ -65,7 +63,6 @@ OC.L10N.register(
     "%s shared »%s« with you" : "%s je s vama podijelio »%s«",
     "Sharing %s failed, because the file does not exist" : "Dijeljenje %s nije uspjelo jer ta datoteka ne postoji",
     "You are not allowed to share %s" : "Nije vam dopušteno dijeliti %s",
-    "Sharing %s failed, because the user %s is the item owner" : "Dijeljenje %s nije uspjelo jer je korisnik %s vlasnik te stavke",
     "Sharing %s failed, because the user %s does not exist" : "Dijeljenje %s nije uspjelo jer korisnik %s ne postoji",
     "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Dijeljenje %s nije uspjelo jer korisnik %s nije član niti jedne grupe u kojoj je %s član",
     "Sharing %s failed, because this item is already shared with %s" : "Dijeljenje %s nije uspjelo jer je ova stavka već podijeljena s %s",
@@ -81,23 +78,26 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Dijeljenje pozadine %s mora implementirati sučelje OCP\\Share_Backend",
     "Sharing backend %s not found" : "Dijeljenje pozadine %s nije nađeno",
     "Sharing backend for %s not found" : "Dijeljenje pozadine za %s nije nađeno",
-    "Sharing %s failed, because the user %s is the original sharer" : "Dijeljenje %s nije uspjelo jer je korisnik %s izvorni djelitelj",
     "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Dijeljenje %s nije uspjelo jer dozvole premašuju dozvole za koje %s ima odobrenje.",
     "Sharing %s failed, because resharing is not allowed" : "Dijeljenje %s nije uspjelo jer ponovno dijeljenje nije dopušteno.",
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "Dijeljenje %s nije uspjelo jer pozadina za %s nije mogla pronaći svoj izvor",
     "Sharing %s failed, because the file could not be found in the file cache" : "Dijeljenje %s nije uspjelo jer u predmemoriji datoteke datoteka nije nađena.",
     "Could not find category \"%s\"" : "Kategorija \"%s\" nije nađena",
-    "Apps" : "Aplikacije",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-\"" : "Samo su sljedeći znakovi dopušteni u korisničkom imenu: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-\"",
     "A valid username must be provided" : "Nužno je navesti ispravno korisničko ime",
     "A valid password must be provided" : "Nužno je navesti ispravnu lozinku",
     "The username is already being used" : "Korisničko ime se već koristi",
+    "Help" : "Pomoć",
+    "Settings" : "Postavke",
+    "Users" : "Korisnici",
+    "web services under your control" : "web usluge pod vašom kontrolom",
+    "Application is not enabled" : "Aplikacija nije aktivirana",
+    "Authentication error" : "Pogrešna autentikacija",
+    "Token expired. Please reload page." : "Token je istekao. Molimo, ponovno učitajte stranicu.",
+    "Unknown user" : "Korisnik nepoznat",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Pogonski programi baze podataka (sqlite, mysql, ili postgresql) nisu instalirani.",
     "Cannot write into \"config\" directory" : "Nije moguće zapisivati u \"config\" direktorij",
     "Cannot write into \"apps\" directory" : "Nije moguće zapisivati u \"apps\" direktorij",
     "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Ovo se obično može popraviti %sdavanjem pristupa web poslužitelju za pisanje u apps direktorij%sili isključivanjem appstorea u konfiguracijskoj datoteci.",
-    "Cannot create \"data\" directory (%s)" : "Kreiranje \"data\" direktorija (%s) nije moguće",
-    "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "Ovo obično može popraviti <a href=\"%s\"target=\"_blank\">davanjem pristupa web poslužiteljuza pisanje u korijenskom direktoriju</a>.",
     "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Dozvole se obično mogu popraviti %sdavanjem pristupa web poslužitelju za pisanje u korijenskom direktoriju%s",
     "Setting locale to %s failed" : "Postavljanje regionalne sheme u %s nije uspjelo",
     "Please install one of these locales on your system and restart your webserver." : "Molimo instalirajte jednu od ovih regionalnih shema u svoj sustav i ponovno pokrenite svoj web poslužitelj.",
@@ -108,11 +108,7 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "Molimo zamolite  svog administratora poslužitelja da ponovno pokrene web poslužitelj.",
     "PostgreSQL >= 9 required" : "Potreban je PostgreSQL >= 9",
     "Please upgrade your database version" : "Molimo, ažurirajte svoju verziju baze podataka",
-    "Error occurred while checking PostgreSQL version" : "Došlo je do pogreške tijekom provjeravanja verzije PostgreSQL",
-    "Please make sure you have PostgreSQL >= 9 or check the logs for more information about the error" : "Pobrinite se da imate PostgreSQL >= 9. Za više informacija provjerite zapisnike.",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Molimo promijenite dozvole na 0770 tako da se tim direktorijem ne mogu služiti drugi korisnici",
-    "Data directory (%s) is readable by other users" : "Podatkovni direktorij (%s) čitljiv je za druge korisnike",
-    "Data directory (%s) is invalid" : "Podatkovni direktorij (%s) nije ispravan",
     "Please check that the data directory contains a file \".ocdata\" in its root." : "Molimo provjerite sadrži li podatkovni direktorij u svom korijenu datoteku \".ocdata\"",
     "Could not obtain lock type %d on \"%s\"." : "Nije moguće dobiti lock tip %d na \"%s\"."
 },
