@@ -1,35 +1,16 @@
 OC.L10N.register(
     "settings",
     {
-    "APCu" : "APCu",
-    "Redis" : "Redis",
-    "Security & setup warnings" : "Biztonsági és telepítési figyelmeztetések",
-    "Sharing" : "Megosztás",
-    "Server-side encryption" : "Szerveroldali titkosítás",
-    "External Storage" : "Külső tárolási szolgáltatások becsatolása",
-    "Cron" : "Ütemezett feladatok",
-    "Email server" : "E-mail szerver",
-    "Log" : "Naplózás",
-    "Tips & tricks" : "Tippek és trükkök",
-    "Updates" : "Frissítések",
-    "Couldn't remove app." : "Az alkalmazást nem sikerült eltávolítani.",
-    "Language changed" : "A nyelv megváltozott",
-    "Invalid request" : "Érvénytelen kérés",
-    "Authentication error" : "Azonosítási hiba",
-    "Admins can't remove themself from the admin group" : "Adminisztrátorok nem távolíthatják el magukat az admin csoportból.",
-    "Unable to add user to group %s" : "A felhasználó nem adható hozzá ehhez a csoporthoz: %s",
-    "Unable to remove user from group %s" : "A felhasználó nem távolítható el ebből a csoportból: %s",
-    "Couldn't update app." : "A program frissítése nem sikerült.",
     "Wrong password" : "Hibás jelszó",
     "No user supplied" : "Nincs megadva felhasználó",
-    "Please provide an admin recovery password, otherwise all user data will be lost" : "Adja meg az admin helyreállítási jelszót, máskülönben az összes felhasználói adat elveszik!",
+    "Authentication error" : "Azonosítási hiba",
     "Wrong admin recovery password. Please check the password and try again." : "Hibás admin helyreállítási jelszó. Ellenőrizze a jelszót és próbálja újra!",
     "Backend doesn't support password change, but the user's encryption key was successfully updated." : "A háttér-alrendszer nem támogatja a jelszómódosítást, de felhasználó titkosítási kulcsát sikeresen frissítettük.",
     "Unable to change password" : "Nem sikerült megváltoztatni a jelszót",
-    "Enabled" : "Engedélyezve",
-    "Not enabled" : "Tiltva",
+    "Couldn't send reset email. Please contact your administrator." : "Visszaállítási e-mail nem küldhető. Kérjük, lépjen kapcsolatba a rendszergazdával.",
     "installing and updating apps via the app store or Federated Cloud Sharing" : "alkalmazások telepítése és frissítése az alkalmazás tárból vagy Szövetséges Felhő Megosztásból",
     "Federated Cloud Sharing" : "Megosztás Egyesített Felhőben",
+    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL elavult %s verziót (%s) használ. Kérjük, frissítse az operációs rendszerét, vagy egyes funkciók (mint például a %s) megbízhatatlanul fognak működni.",
     "A problem occurred, please check your log files (Error: %s)" : "Probléma történt, kérjük nézd meg a naplófájlokat (Hiba: %s).",
     "Migration Completed" : "Migráció kész!",
     "Group already exists." : "A csoport már létezik.",
@@ -49,38 +30,52 @@ OC.L10N.register(
     "Forbidden" : "Tiltott",
     "Invalid user" : "Érvénytelen felhasználó",
     "Unable to change mail address" : "Nem lehet megváltoztatni az e-mail címet",
-    "Email saved" : "E-mail elmentve!",
     "Your full name has been changed." : "Az Ön teljes nevét módosítottuk.",
     "Unable to change full name" : "Nem sikerült megváltoztatni a teljes nevét",
-    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Biztos abban, hogy hozzá akarja adni \"{domain}\"-t a megbízható tartományokhoz?",
-    "Add trusted domain" : "Megbízható tartomány hozzáadása",
-    "Migration in progress. Please wait until the migration is finished" : "Migráció folyamatban. Kérjük várj, míg a migráció befejeződik.",
-    "Migration started …" : "Migráció elindítva ...",
-    "Sending..." : "Küldés...",
+    "APCu" : "APCu",
+    "Redis" : "Redis",
+    "__language_name__" : "__language_name__",
+    "Language changed" : "A nyelv megváltozott",
+    "Invalid request" : "Érvénytelen kérés",
+    "Admins can't remove themself from the admin group" : "Adminisztrátorok nem távolíthatják el magukat az admin csoportból.",
+    "Unknown user" : "Ismeretlen felhasználó",
+    "Couldn't remove app." : "Az alkalmazást nem sikerült eltávolítani.",
     "Official" : "Hivatalos",
     "Approved" : "Jóváhagyott",
-    "Experimental" : "Kísérleti",
     "All" : "Mind",
+    "Enabled" : "Engedélyezve",
+    "Not enabled" : "Tiltva",
     "No apps found for your version" : "Nem található alkalmazás a verziód számára",
+    "The app will be downloaded from the app store" : "Az alkalmazás letöltésre kerül az alkalmazástárból",
     "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "A hivatalos alkalmazásokat az ownCloud közösségen belül fejlesztik. \nAz általuk nyújtott központi ownCloud funkciók készen állnak a produktív használatra.",
+    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "A jóváhagyott alkalmazásokat megbízható fejlesztők készítik, amik megfelelnek a felületes biztonsági ellenőrzésnek. Nyílt forráskódú tárolóban aktívan karbantartják és biztosítják a stabil használatot.",
     "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Ez az alkalmazás még nincs biztonságilag ellenőrizve és vagy új, vagy ismert instabil. Telepítés csak saját felelősségre!",
-    "Update to %s" : "Frissítés erre: %s",
     "Please wait...." : "Kérjük várj...",
     "Error while disabling app" : "Hiba az alkalmazás letiltása közben",
     "Disable" : "Letiltás",
     "Enable" : "Engedélyezés",
     "Error while enabling app" : "Hiba az alkalmazás engedélyezése közben",
+    "Error: this app cannot be enabled because it makes the server unstable" : "Hiba: ezt az alkalmzást nem lehet engedélyezni, mert a szerver instabilitását eredményezné",
+    "Error: could not disable broken app" : "Hiba: nem lehet tiltani a megtört alkalmazást",
+    "Error while disabling broken app" : "Hiba történt a megtört alkalmazás tiltása közben",
     "Updating...." : "Frissítés folyamatban...",
     "Error while updating app" : "Hiba történt az alkalmazás frissítése közben",
     "Updated" : "Frissítve",
     "Uninstalling ...." : "Eltávolítás ...",
     "Error while uninstalling app" : "Hiba történt az alkalmazás eltávolítása közben",
     "Uninstall" : "Eltávolítás",
+    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Ez az alkalmazás engedélyezve van, de frissíteni kell. A frissítő oldalra irányítjuk 5 másodpercen belül.",
     "App update" : "Alkalmazás frissítése",
-    "No apps found for \"{query}\"" : "Nem található alkalmazás a „{query}” lekérdezésre.",
+    "Experimental" : "Kísérleti",
+    "No apps found for {query}" : "{query} keresésre nincs találat",
+    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Biztos abban, hogy hozzá akarja adni \"{domain}\"-t a megbízható tartományokhoz?",
+    "Add trusted domain" : "Megbízható tartomány hozzáadása",
+    "Migration in progress. Please wait until the migration is finished" : "Migráció folyamatban. Kérjük várj, míg a migráció befejeződik.",
+    "Migration started …" : "Migráció elindítva ...",
     "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Hiba történt! Kérem töltsön fel egy, ASCII karakterekkel kódolt PEM tanusítványt!",
     "Valid until {date}" : "Érvényes: {date}",
     "Delete" : "Törlés",
+    "Sending..." : "Küldés...",
     "An error occurred: {message}" : "Hiba történt: {message}",
     "Select a profile picture" : "Válasszon profilképet!",
     "Very weak password" : "Nagyon gyenge jelszó",
@@ -90,68 +85,63 @@ OC.L10N.register(
     "Strong password" : "Erős jelszó",
     "Groups" : "Csoportok",
     "Unable to delete {objName}" : "Ezt nem sikerült törölni: {objName}",
+    "Error creating group: {message}" : "Hiba történt a csoport létrehozásakor: {message}",
     "A valid group name must be provided" : "Érvényes csoportnevet kell megadni",
     "deleted {groupName}" : "törölve: {groupName}",
     "undo" : "visszavonás",
-    "no group" : "nincs csoport",
     "never" : "soha",
     "deleted {userName}" : "törölve: {userName}",
     "add group" : "csoport hozzáadása",
+    "enabled" : "Bekapcsolva",
+    "disabled" : "Kikapcsolva",
+    "no group" : "nincs csoport",
     "Changing the password will result in data loss, because data recovery is not available for this user" : "A jelszó megváltoztatása adatvesztéssel jár, mert lehetséges az adatok visszaállítása ennek a felhasználónak",
     "A valid username must be provided" : "Érvényes felhasználónevet kell megadnia",
+    "Error creating user: {message}" : "Hiba történt a felhasználó létrehozásakor: {message}",
     "A valid password must be provided" : "Érvényes jelszót kell megadnia",
     "A valid email must be provided" : "Érvényes e-mail címet kell megadni",
-    "__language_name__" : "__language_name__",
-    "Personal info" : "Személyes információk",
-    "Sync clients" : "Szinkronizáló kliensek",
-    "Everything (fatal issues, errors, warnings, info, debug)" : "Minden (végzetes hibák, hibák, figyelmeztetések, információk, hibakeresési üzenetek)",
-    "Info, warnings, errors and fatal issues" : "Információk, figyelmeztetések, hibák és végzetes hibák",
-    "Warnings, errors and fatal issues" : "Figyelmeztetések, hibák és végzetes hibák",
-    "Errors and fatal issues" : "Hibák és végzetes hibák",
-    "Fatal issues only" : "Csak a végzetes hibák",
-    "None" : "Egyik sem",
-    "Login" : "Login",
-    "Plain" : "Plain",
-    "NT LAN Manager" : "NT LAN Manager",
-    "SSL" : "SSL",
-    "TLS" : "TLS",
-    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "Úgy tűnik, hogy a PHP nem tudja olvasni a rendszer környezeti változóit. A getenv(\"PATH\") teszt visszatérési értéke üres.",
-    "Please check the <a target=\"_blank\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Kérjük ellenőrizd a <a target=\"_blank\" href=\"%s\">telepítési dokumentációt ↗</a> a PHP konfigurációs beállításaival kapcsolatban, főleg ha PHP-FPM-et használsz.",
-    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "Úgy tűnik, hogy a PHP úgy van beállítva, hogy eltávolítja programok belsejében elhelyezett szövegblokkokat. Emiatt a rendszer több alapvető fontosságú eleme működésképtelen lesz.",
-    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Ezt valószínűleg egy gyorsítótár ill. kódgyorsító, mint pl, a Zend, OPcache vagy eAccelererator okozza.",
-    "Your server is running on Microsoft Windows. We highly recommend Linux for optimal user experience." : "A szervered Microsoft Windowson fut. A legjobb felhasználói élményért erősen javasoljuk, hogy Linuxot használj.",
-    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "A 'fileinfo' PHP modul hiányzik. Erősen javasolt ennek a modulnak a telepítése, mert ezzel lényegesen jobb a MIME-típusok felismerése.",
-    "System locale can not be set to a one which supports UTF-8." : "A rendszer lokalizációs állományai között nem sikerült olyat beállítani, ami támogatja az UTF-8-at.",
-    "This means that there might be problems with certain characters in file names." : "Ez azt jelenti, hogy probléma lehet bizonyos karakterekkel a fájlnevekben.",
-    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Feltétlenül javasoljuk, hogy telepítse a szükséges csomagokat ahhoz, hogy a rendszere támogassa a következő lokalizációk valamelyikét: %s",
-    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Ha a telepítése nem a webkiszolgáló gyökerében van, és a rendszer cron szolgáltatását használja, akkor problémák lehetnek az URL-ek képzésével. Ezek elkerülése érdekében állítsa be a config.php-ban az \"overwrite.cli.url\" paramétert a telepítés által használt webútvonalra. (Javasolt beállítás: \"%s\")",
-    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Az ütemezett feladat (cronjob) nem futott le parancssorból. A következő hibák tűntek fel:",
-    "All checks passed." : "Minden ellenőrzés sikeres.",
-    "Open documentation" : "Dokumentáció megnyitása",
-    "Allow apps to use the Share API" : "Lehetővé teszi, hogy a programmodulok is használhassák a megosztást",
-    "Allow users to share via link" : "Engedjük meg az állományok linkekkel történő megosztását",
-    "Enforce password protection" : "Legyen kötelező a linkek jelszóval való védelme",
-    "Allow public uploads" : "Nyilvános feltöltés engedélyezése",
-    "Allow users to send mail notification for shared files" : "A felhasználók küldhessenek e-mail értesítést a megosztás létrejöttéről",
-    "Set default expiration date" : "Alapértelmezett lejárati idő beállítása",
-    "Expire after " : "A lejárat legyen",
-    "days" : "nap",
-    "Enforce expiration date" : "A beállított lejárati idő legyen kötelezően érvényes",
-    "Allow resharing" : "A megosztás továbbadásának engedélyezése",
-    "Restrict users to only share with users in their groups" : "A csoporttagok csak a saját csoportjukon belül oszthassanak meg anyagokat",
-    "Allow users to send mail notification for shared files to other users" : "A felhasználók küldhessenek más felhasználóknak e-mail értesítést a megosztott fájlokról",
-    "Exclude groups from sharing" : "Csoportok megosztási jogának tiltása",
-    "These groups will still be able to receive shares, but not to initiate them." : "E csoportok tagjaival meg lehet osztani anyagokat, de ők nem hozhatnak létre megosztást.",
-    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "Felhasználónév automatikus befejezése engedélyezése a megosztás ablakban. Ha le van tiltva, akkor a teljes felhasználónevet kell beírni.",
+    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Üdv!<br><br>Értesítünk, hogy van egy %s fiókja.<br><br>Felhasználónév: %s<br>Hozzáférés: <a href=\"%s\">%s</a><br><br>",
+    "Cheers!" : "Üdv.",
+    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Üdv!\n\nÉrtesítünk, hogy van egy %s fiókja.\n\nFelhasználónév: %s\nHozzáférés: %s\n\n",
+    "User documentation" : "Felhasználói dokumentáció",
+    "Administrator documentation" : "Adminisztrátori dokumentáció",
+    "Online documentation" : "Online dokumentáció",
+    "Forum" : "Fórum",
+    "Issue tracker" : "Hibabejelentések",
+    "Commercial support" : "Kereskedelmi támogatás",
+    "Developer documentation" : "Fejlesztői dokumentáció",
+    "by %s" : "készítő: %s",
+    "%s-licensed" : "%s-licencelt",
+    "Documentation:" : "Dokumentációk:",
+    "Admin documentation" : "Adminisztrátori dokumentáció",
+    "Show description …" : "Leírás megjelenítése ...",
+    "Hide description …" : "Leírás elrejtése ...",
+    "This app has no minimum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Ennek az alkalmazásnak nincs minimális ownCloud verzió megadva. Ez hibát okoz majd az ownCloud 11-es és későbbi verziókban.",
+    "This app has no maximum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Ennek az alkalmazásnak nincs maximális ownCloud verzió megadva. Ez hibát okoz majd az ownCloud 11-es és későbbi verziókban.",
+    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ezt az applikációt nem lehet telepíteni, mert a következő függőségek hiányoznak:",
+    "Enable only for specific groups" : "Csak bizonyos csoportok számára tegyük elérhetővé",
+    "Uninstall App" : "Alkalmazás eltávolítása",
+    "Cron" : "Ütemezett feladatok",
     "Last cron job execution: %s." : "Az utolsó cron feladat ekkor futott le: %s.",
     "Last cron job execution: %s. Something seems wrong." : "Az utolsó cron feladat ekkor futott le: %s. Valami nincs rendben.",
     "Cron was not executed yet!" : "A cron feladat még nem futott le!",
+    "Open documentation" : "Dokumentáció megnyitása",
     "Execute one task with each page loaded" : "Egy-egy feladat végrehajtása minden alkalommal, amikor egy weboldalt letöltenek",
     "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "A cron.php webcron szolgáltatásként van regisztrálva, hogy 15 percenként egyszer lefuttassa a cron.php-t.",
     "Use system's cron service to call the cron.php file every 15 minutes." : "A rendszer cron szolgáltatását használjuk, mely a cron.php állományt futtatja le 15 percenként.",
+    "SSL Root Certificates" : "SSL Root tanusítványok",
+    "Common Name" : "Általános Név",
+    "Valid until" : "Érvényes",
+    "Issued By" : "Kiadta",
+    "Valid until %s" : "Érvényes: %s",
+    "Import root certificate" : "Gyökértanúsítvány importálása",
+    "Server-side encryption" : "Szerveroldali titkosítás",
     "Enable server-side encryption" : "Szerveroldali titkosítás engedélyezése",
     "Please read carefully before activating server-side encryption: " : "Kérjük, ezt olvasd el figyelmesen mielőtt engedélyezed a szerveroldali titkosítást:",
+    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Ha egyszer engedélyezve lett a titkosítás, akkor onnantól kezdve a szerveren az összes fájl titkosításra kerül, melyet később csak akkor lehet visszafordítani, ha azt az aktív titkosítási modul támogatja és minden elő-követelmény (például helyreállító kulcs) teljesül.",
+    "Encryption alone does not guarantee security of the system. Please see ownCloud documentation for more information about how the encryption app works, and the supported use cases." : "A titkosítás nem garantálja a rendszer biztonságát. Kérjük, bővebb információért keresse fel az ownCloud dokumentációját, ahol megtudhatja, hogy hogyan működik a titkosító alkalmazás és mikor érdemes használni.",
     "Be aware that encryption always increases the file size." : "Ügyeljen arra, hogy a titkosítás mindig megnöveli a fájl méretét!",
+    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Mindig jó ötlet rendszeres biztonsági mentést készíteni az adatokról. Titkosítás esetén a titkosító kulcsok biztonsági mentését elkülönítve tárolja az adatoktól!",
     "This is the final warning: Do you really want to enable encryption?" : "Ez az utolsó figyelmeztetés: Biztosan szeretnéd engedélyezni a titkosítást?",
     "Enable encryption" : "Titkosítás engedélyezése",
     "No encryption module loaded, please enable an encryption module in the app menu." : "Nincs titkosítási modul betöltve, kérjük engedélyezd a titkosítási modult az alkalmazások menüben.",
@@ -159,6 +149,38 @@ OC.L10N.register(
     "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Migrálni kell a titkosítási kulcsokat a régi titkosításból (ownCloud <= 8.0) egy újba. Kérjük, engedélyezd az „Alapértelmezett titkosítási modul”-t és futtasd ezt: occ encryption:migrate",
     "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Migrálni kell a titkosítási kulcsokat a régi titkosításból (ownCloud <= 8.0) egy újba.",
     "Start migration" : "Migrálás indítása",
+    "Sharing" : "Megosztás",
+    "Allow apps to use the Share API" : "Lehetővé teszi, hogy a programmodulok is használhassák a megosztást",
+    "Allow users to share via link" : "Engedjük meg az állományok linkekkel történő megosztását",
+    "Allow public uploads" : "Nyilvános feltöltés engedélyezése",
+    "Enforce password protection" : "Legyen kötelező a linkek jelszóval való védelme",
+    "Set default expiration date" : "Alapértelmezett lejárati idő beállítása",
+    "Allow users to send mail notification for shared files" : "A felhasználók küldhessenek e-mail értesítést a megosztás létrejöttéről",
+    "Expire after " : "A lejárat legyen",
+    "days" : "nap",
+    "Enforce expiration date" : "A beállított lejárati idő legyen kötelezően érvényes",
+    "Allow resharing" : "A megosztás továbbadásának engedélyezése",
+    "Allow sharing with groups" : "Megosztás engedélyezése a csoportokkal",
+    "Restrict users to only share with users in their groups" : "A csoporttagok csak a saját csoportjukon belül oszthassanak meg anyagokat",
+    "Allow users to send mail notification for shared files to other users" : "A felhasználók küldhessenek más felhasználóknak e-mail értesítést a megosztott fájlokról",
+    "Exclude groups from sharing" : "Csoportok megosztási jogának tiltása",
+    "These groups will still be able to receive shares, but not to initiate them." : "E csoportok tagjaival meg lehet osztani anyagokat, de ők nem hozhatnak létre megosztást.",
+    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "Felhasználónév automatikus befejezése engedélyezése a megosztás ablakban. Ha le van tiltva, akkor a teljes felhasználónevet kell beírni.",
+    "Everything (fatal issues, errors, warnings, info, debug)" : "Minden (végzetes hibák, hibák, figyelmeztetések, információk, hibakeresési üzenetek)",
+    "Info, warnings, errors and fatal issues" : "Információk, figyelmeztetések, hibák és végzetes hibák",
+    "Warnings, errors and fatal issues" : "Figyelmeztetések, hibák és végzetes hibák",
+    "Errors and fatal issues" : "Hibák és végzetes hibák",
+    "Fatal issues only" : "Csak a végzetes hibák",
+    "Log" : "Naplózás",
+    "What to log" : "Mit naplózzon",
+    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "A naplófájl 100MB-nál nagyobb. A letöltése hosszabb időt vehet igénybe.",
+    "None" : "Egyik sem",
+    "Login" : "Login",
+    "Plain" : "Plain",
+    "NT LAN Manager" : "NT LAN Manager",
+    "SSL/TLS" : "SSL/TLS",
+    "STARTTLS" : "STARTTLS",
+    "Email server" : "E-mail szerver",
     "This is used for sending out notifications." : "Ezt használjuk a jelentések kiküldésére.",
     "Send mode" : "Küldési mód",
     "Encryption" : "Titkosítás",
@@ -174,51 +196,39 @@ OC.L10N.register(
     "Store credentials" : "Azonosítók eltárolása",
     "Test email settings" : "Az e-mail beállítások ellenőrzése",
     "Send email" : "E-mail küldése",
-    "Download logfile" : "Naplófájl letöltése",
-    "More" : "Több",
-    "Less" : "Kevesebb",
-    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "A naplófájl 100MB-nál nagyobb. A letöltése hosszabb időt vehet igénybe.",
-    "What to log" : "Mit naplózzon",
+    "Security & setup warnings" : "Biztonsági és telepítési figyelmeztetések",
+    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "Úgy tűnik, hogy a PHP nem tudja olvasni a rendszer környezeti változóit. A getenv(\"PATH\") teszt visszatérési értéke üres.",
+    "Please check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Kérjük, ellenőrizze a <a target=\"_blank\" rel=\"noreferrer\"  href=\"%s\">telepítési dokumentációt ↗</a> a PHP konfigurációs beállításaival kapcsolatban, főleg ha PHP-FPM-et használ.",
+    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Csak olvasható beállítófájl engedélyezve. Ez meggátolja a beállítások módosítását a webes felületről. Továbbá, a fájlt kézzel kell írhatóvá tenni minden frissítés alkalmával.",
+    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "Úgy tűnik, hogy a PHP úgy van beállítva, hogy eltávolítja programok belsejében elhelyezett szövegblokkokat. Emiatt a rendszer több alapvető fontosságú eleme működésképtelen lesz.",
+    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Ezt valószínűleg egy gyorsítótár ill. kódgyorsító, mint pl, a Zend, OPcache vagy eAccelererator okozza.",
+    "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version." : "%1$s %2$s verziója van telepítve, de a stabilitási és teljesítményi okok miatt javasoljuk az újabb, %1$s verzióra való frissítést.",
+    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "A 'fileinfo' PHP modul hiányzik. Erősen javasolt ennek a modulnak a telepítése, mert ezzel lényegesen jobb a MIME-típusok felismerése.",
+    "System locale can not be set to a one which supports UTF-8." : "A rendszer lokalizációs állományai között nem sikerült olyat beállítani, ami támogatja az UTF-8-at.",
+    "This means that there might be problems with certain characters in file names." : "Ez azt jelenti, hogy probléma lehet bizonyos karakterekkel a fájlnevekben.",
+    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Feltétlenül javasoljuk, hogy telepítse a szükséges csomagokat ahhoz, hogy a rendszere támogassa a következő lokalizációk valamelyikét: %s",
+    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Ha a telepítése nem a webkiszolgáló gyökerében van, és a rendszer cron szolgáltatását használja, akkor problémák lehetnek az URL-ek képzésével. Ezek elkerülése érdekében állítsa be a config.php-ban az \"overwrite.cli.url\" paramétert a telepítés által használt webútvonalra. (Javasolt beállítás: \"%s\")",
     "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "Adatbázisként az SQLite-ot fogjuk használni. Nagyobb telepítések esetén javasoljuk, hogy váltson másik adatbázis háttérkiszolgálóra",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Amikor az asztali klienset használja fálj szinkronizációra, akkor az SQLite használata nem ajánlott.",
+    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a>." : "Más adatbázisról való áttéréshez használja a parancssort: 'occ db:convert-type', vagy keresse fel a <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">dokumentációt ↗</a>.",
+    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Az ütemezett feladat (cronjob) nem futott le parancssorból. A következő hibák tűntek fel:",
+    "Please double check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Kérjük, ellenőrizze a <a target=\"_blank\" rel=\"noreferrer\"  href=\"%s\">telepítési dokumentációt ↗</a> és ellenőrizze a <a href=\"#log-section\">naplófájlt</a>, hogy tartalmaz-e bármilyen hibát vagy figyelmeztetést.",
+    "All checks passed." : "Minden ellenőrzés sikeres.",
+    "Tips & tricks" : "Tippek és trükkök",
     "How to do backups" : "Hogyan csináljunk biztonsági mentéseket",
     "Advanced monitoring" : "Haladó monitorozás",
     "Performance tuning" : "Teljesítményi hangolás",
     "Improving the config.php" : "config.php javítása",
     "Theming" : "Témázás",
     "Hardening and security guidance" : "Erősítési és biztonsági útmutató",
-    "Version" : "Verzió",
-    "Developer documentation" : "Fejlesztői dokumentáció",
-    "Experimental applications ahead" : "Kísérleti alkalmazások előre",
-    "Experimental apps are not checked for security issues, new or known to be unstable and under heavy development. Installing them can cause data loss or security breaches." : "A kísérleti applikációk nincsenek biztonsági ellenőrizve, ismert vagy ismeretlen hibák lehetnek bennük és aktív fejlesztés alatt állnak. A telepítésük adatvesztéshez vezethet, vagy biztonsági kockázata lehet.",
-    "Documentation:" : "Dokumentációk:",
-    "User documentation" : "Felhasználói dokumentáció",
-    "Admin documentation" : "Adminisztrátori dokumentáció",
-    "Show description …" : "Leírás megjelenítése ...",
-    "Hide description …" : "Leírás elrejtése ...",
-    "This app has no minimum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Ennek az alkalmazásnak nincs minimális ownCloud verzió megadva. Ez hibát okoz majd az ownCloud 11-es és későbbi verziókban.",
-    "This app has no maximum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Ennek az alkalmazásnak nincs maximális ownCloud verzió megadva. Ez hibát okoz majd az ownCloud 11-es és későbbi verziókban.",
-    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ezt az applikációt nem lehet telepíteni, mert a következő függőségek hiányoznak:",
-    "Enable only for specific groups" : "Csak bizonyos csoportok számára tegyük elérhetővé",
-    "Uninstall App" : "Alkalmazás eltávolítása",
-    "Enable experimental apps" : "Kísérleti alkalmazások engedélyezése",
-    "SSL Root Certificates" : "SSL Root tanusítványok",
-    "Common Name" : "Általános Név",
-    "Valid until" : "Érvényes",
-    "Issued By" : "Kiadta",
-    "Valid until %s" : "Érvényes: %s",
-    "Import root certificate" : "Gyökértanúsítvány importálása",
-    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Üdv!<br><br>Értesítünk, hogy van egy %s fiókja.<br><br>Felhasználónév: %s<br>Hozzáférés: <a href=\"%s\">%s</a><br><br>",
-    "Cheers!" : "Üdv.",
-    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Üdv!\n\nÉrtesítünk, hogy van egy %s fiókja.\n\nFelhasználónév: %s\nHozzáférés: %s\n\n",
-    "Administrator documentation" : "Adminisztrátori dokumentáció",
-    "Online documentation" : "Online dokumentáció",
-    "Forum" : "Fórum",
-    "Issue tracker" : "Hibabejelentések",
-    "Commercial support" : "Kereskedelmi támogatás",
-    "You are using <strong>%s</strong> of <strong>%s</strong>" : "Jelenleg használt: <strong>%s</strong>, maximálisan elérhető: <strong>%s</strong>",
+    "Get the apps to sync your files" : "Töltse le az állományok szinkronizációjához szükséges programokat!",
+    "Desktop client" : "Asztali kliens",
+    "Android app" : "Android applikáció",
+    "iOS app" : "IOS applikáció",
+    "Show First Run Wizard again" : "Nézzük meg újra az első bejelentkezéskori segítséget!",
     "Profile picture" : "Profilkép",
     "Upload new" : "Új feltöltése",
+    "Select from Files" : "Kiválasztás a Fájlkból",
     "Remove image" : "A kép eltávolítása",
     "png or jpg, max. 20 MB" : "png vagy jpg, max. 20 MB",
     "Cancel" : "Mégsem",
@@ -227,6 +237,7 @@ OC.L10N.register(
     "No display name set" : "Nincs megjelenítési név beállítva",
     "Email" : "E-mail",
     "Your email address" : "Az Ön e-mail címe",
+    "For password recovery and notifications" : "Jelszó helyreállításhoz és értesítésekhez",
     "No email address set" : "Nincs e-mail cím beállítva",
     "You are member of the following groups:" : "Tagja vagy a következő csoport(ok)nak:",
     "Password" : "Jelszó",
@@ -236,19 +247,20 @@ OC.L10N.register(
     "Change password" : "A jelszó megváltoztatása",
     "Language" : "Nyelv",
     "Help translate" : "Segítsen a fordításban!",
-    "Get the apps to sync your files" : "Töltse le az állományok szinkronizációjához szükséges programokat!",
-    "Desktop client" : "Asztali kliens",
-    "Android app" : "Android applikáció",
-    "iOS app" : "IOS applikáció",
-    "If you want to support the project\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\tor\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "Ha segíteni szeretnéd a projektet\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">csatlakozz a fejlesztéshez</a>\n\t\tvagy\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">hirdesd az igét</a>!",
-    "Show First Run Wizard again" : "Nézzük meg újra az első bejelentkezéskori segítséget!",
+    "Unlimited" : "Korlátlan",
     "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "{communityopen}ownCloud közösség{linkclose} fejleszti, a {githubopen}forráskód{linkclose} {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose} licenc alatt licencelve.",
+    "Name" : "Név",
+    "Username" : "Felhasználónév",
+    "Done" : "Kész",
+    "Version" : "Verzió",
+    "Personal" : "Személyes",
+    "Admin" : "Adminsztráció",
+    "Error" : "Hiba",
     "Show storage location" : "Háttértároló helyének mutatása",
     "Show last log in" : "Utolsó bejelentkezés megjelenítése",
     "Show user backend" : "Felhasználói háttér mutatása",
     "Send email to new user" : "E-mail küldése az új felhasználónak",
     "Show email address" : "E-mail cím megjelenítése",
-    "Username" : "Felhasználónév",
     "E-Mail" : "E-mail",
     "Create" : "Létrehozás",
     "Admin Recovery Password" : "Adminisztrátori jelszó az állományok visszanyerésére",
@@ -259,7 +271,6 @@ OC.L10N.register(
     "Admins" : "Adminok",
     "Default Quota" : "Alapértelmezett kvóta",
     "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Kérjük adja meg a tárolási kvótát (pl.  \"512 MB\" vagy \"12 GB\")",
-    "Unlimited" : "Korlátlan",
     "Other" : "Más",
     "Full Name" : "Teljes név",
     "Group Admin for" : "Csoport Adminisztrátor itt",
