@@ -1,33 +1,16 @@
 OC.L10N.register(
     "settings",
     {
-    "APCu" : "APCu",
-    "Redis" : "Redis",
-    "Security & setup warnings" : "安全及设置警告",
-    "Sharing" : "共享",
-    "Server-side encryption" : "服务器端加密",
-    "External Storage" : "外部存储",
-    "Cron" : "计划任务",
-    "Email server" : "电子邮件服务器",
-    "Log" : "日志",
-    "Tips & tricks" : "技巧提示",
-    "Updates" : "更新",
-    "Couldn't remove app." : "无法删除应用。",
-    "Language changed" : "语言已修改",
-    "Invalid request" : "无效请求",
-    "Authentication error" : "认证错误",
-    "Admins can't remove themself from the admin group" : "管理员不能将自己移出管理组。",
-    "Unable to add user to group %s" : "无法把用户增加到组 %s",
-    "Unable to remove user from group %s" : "无法从组%s中移除用户",
-    "Couldn't update app." : "无法更新 app。",
-    "Wrong password" : "错误密码",
+    "Wrong password" : "密码错误",
+    "The new password can not be the same as the previous one" : "新密码不能和之前的密码相同",
     "No user supplied" : "没有满足的用户",
-    "Please provide an admin recovery password, otherwise all user data will be lost" : "请提供管理员恢复密码，否则所有用户的数据都将遗失。",
+    "Authentication error" : "认证错误",
+    "Please provide an admin recovery password; otherwise, all user data will be lost." : "请提供管理员恢复密码; 否则，所有用户数据将丢失。",
     "Wrong admin recovery password. Please check the password and try again." : "错误的管理员恢复密码。请检查密码并重试。",
     "Backend doesn't support password change, but the user's encryption key was successfully updated." : "后端不支持密码更改，但用户的加密密钥已成功更新。",
     "Unable to change password" : "不能更改密码",
-    "Enabled" : "开启",
-    "Not enabled" : "未启用",
+    "%s password changed successfully" : "%s 密码修改成功",
+    "Couldn't send reset email. Please contact your administrator." : "未能成功发送重置邮件，请联系管理员。",
     "installing and updating apps via the app store or Federated Cloud Sharing" : "通过应用程序商店或联合云共享安装和更新应用程序",
     "Federated Cloud Sharing" : "联合云共享",
     "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL使用了过时 %s 版本 (%s)。请更新你的操作系统或功能比如 %s 将无法可靠地工作。",
@@ -42,6 +25,8 @@ OC.L10N.register(
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "在发送电子邮件时出现问题。请修改您的设置。 (错误: %s)",
     "Email sent" : "邮件已发送",
     "You need to set your user email before being able to send test emails." : "在发送测试邮件前您需要设置您的用户电子邮件。",
+    "Couldn't change the email address because the user does not exist" : "由于用户不存在，无法更改电子邮件地址",
+    "Couldn't change the email address because the token is invalid" : "无法更改电子邮件地址，因为该令牌无效",
     "Invalid mail address" : "无效的电子邮件地址",
     "A user with that name already exists." : "使用该名称的用户已存在。",
     "Unable to create user." : "无法创建用户。",
@@ -50,40 +35,66 @@ OC.L10N.register(
     "Forbidden" : "被禁止",
     "Invalid user" : "用户无效",
     "Unable to change mail address" : "无法更改邮箱地址",
-    "Email saved" : "电子邮件已保存",
+    "Email has been changed successfully." : "已成功修改邮箱地址",
+    "An email has been sent to this address for confirmation" : "电子邮件已发送到这个地址进行确认",
+    "No email was sent because you already sent one recently. Please try again later." : "由于您最近已发送电子邮件，因此没有发送电子邮件。 请稍后再试。",
     "Your full name has been changed." : "您的全名已修改。",
     "Unable to change full name" : "无法修改全名",
-    "Are you really sure you want add \"{domain}\" as trusted domain?" : "你真的希望添加 \"{domain}\" 为信任域？",
-    "Add trusted domain" : "添加信任域",
-    "Migration in progress. Please wait until the migration is finished" : "迁移正在进行中。请等待，直到完成迁移",
-    "Migration started …" : "迁移开始...",
-    "Sending..." : "正在发送...",
+    "%s email address confirm" : "%s 电子邮件地址确认",
+    "Couldn't send email address change confirmation mail. Please contact your administrator." : "无法发送电子邮件地址更改确认邮件。 请联系您的管理员。",
+    "%s email address changed successfully" : "%s 电子邮件地址更改成功。",
+    "Couldn't send email address change notification mail. Please contact your administrator." : "无法发送电子邮件地址更改通知邮件。请与管理员联系。",
+    "Unable to enable/disable user." : "无法启用/禁用用户。",
+    "APCu" : "APCu",
+    "Redis" : "Redis",
+    "__language_name__" : "简体中文",
+    "Language changed" : "语言已修改",
+    "Invalid request" : "无效请求",
+    "Admins can't remove themself from the admin group" : "管理员不能将自己移出管理组。",
+    "Unknown user" : "未知用户",
+    "Couldn't remove app." : "无法删除应用。",
     "Official" : "官方",
     "Approved" : "已认可",
-    "Experimental" : "实验",
     "All" : "全部",
+    "Enabled" : "开启",
+    "Not enabled" : "未启用",
     "No apps found for your version" : "未找到适合当前版本的应用",
+    "The app will be downloaded from the app store" : "此应用将从应用商店下载",
     "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "官方应用是由 ownCloud 社区开发。他们提供 ownCloud 的功能核心并准备用于生产。",
     "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "已认可的应用是由值得信赖的开发商开发，并已通过了一个粗略的安全检查。他们放在一个开放的代码库并且维护人员认为他们是稳定的差不多可以正常使用。",
     "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "此应用未检查安全问题，它是新的或已知是不稳定的。安装风险自担。",
-    "Update to %s" : "更新为 %s",
     "Please wait...." : "请稍等....",
-    "Error while disabling app" : "禁用 app 时出错",
+    "Error while disabling app" : "禁用应用时出错",
     "Disable" : "禁用",
     "Enable" : "开启",
-    "Error while enabling app" : "启用 app 时出错",
+    "Error while enabling app" : "启用应用时出错",
+    "Error: this app cannot be enabled because it makes the server unstable" : "错误: 无法启用应用因为它会导致服务器不稳定",
+    "Error: could not disable broken app" : "错误: 无法禁用损坏的应用",
+    "Error while disabling broken app" : "禁用损坏的应用时出错",
     "Updating...." : "正在更新....",
-    "Error while updating app" : "更新 app 时出错",
+    "Error while updating app" : "更新应用时出错",
     "Updated" : "已更新",
     "Uninstalling ...." : "卸载中....",
     "Error while uninstalling app" : "卸载应用时发生了一个错误",
     "Uninstall" : "卸载",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "该应用已启用，但是需要更新。5秒后将跳转到更新页面。",
     "App update" : "应用更新",
-    "No apps found for \"{query}\"" : "未找到应用适合 \"{query}\"",
+    "Experimental" : "实验",
+    "No apps found for {query}" : "未找到应用适合 \"{query}\"",
+    "Are you really sure you want add \"{domain}\" as trusted domain?" : "你真的希望添加 \"{domain}\" 为信任域？",
+    "Add trusted domain" : "添加信任域",
+    "Migration in progress. Please wait until the migration is finished" : "迁移正在进行中。请等待，直到完成迁移",
+    "Migration started …" : "迁移开始...",
     "An error occurred. Please upload an ASCII-encoded PEM certificate." : "出现了一个错误。请上传 ASCII 编码的 PEM 证书。",
     "Valid until {date}" : "有效期至 {date}",
     "Delete" : "删除",
+    "Disconnect" : "断开连接",
+    "Error while loading browser sessions and device tokens" : "加载浏览器会话和设备令牌时出错",
+    "Error while creating device token" : "创建设备令牌时出错",
+    "Error while deleting the token" : "删除令牌时出错",
+    "Sending..." : "正在发送...",
+    "Failed to change the email address." : "更改电子邮件地址失败。",
+    "Email changed successfully." : "Email 更改成功。",
     "An error occurred: {message}" : "发生错误： {message}",
     "Select a profile picture" : "选择头像",
     "Very weak password" : "非常弱的密码",
@@ -93,68 +104,67 @@ OC.L10N.register(
     "Strong password" : "强密码",
     "Groups" : "组",
     "Unable to delete {objName}" : "无法删除 {objName}",
+    "Error creating group: {message}" : "创建组时出错: {message}",
     "A valid group name must be provided" : "请提供一个有效的组名称",
     "deleted {groupName}" : "已删除 {groupName}",
     "undo" : "撤销",
-    "no group" : "没有组",
     "never" : "从不",
     "deleted {userName}" : "已删除 {userName}",
     "add group" : "增加组",
+    "Invalid quota value \"{val}\"" : "无效值 \"{val}\"",
+    "enabled" : "已启用",
+    "disabled" : "已禁用",
+    "User {uid} has been {state}!" : "用户 {uid} 已被 {state}!",
+    "no group" : "没有组",
     "Changing the password will result in data loss, because data recovery is not available for this user" : "更改密码会导致数据丢失，因为数据恢复不适用于此用户",
+    "Password successfully changed" : "密码修改成功",
     "A valid username must be provided" : "必须提供合法的用户名",
+    "Error creating user: {message}" : "创建用户出错: {message}",
     "A valid password must be provided" : "必须提供合法的密码",
     "A valid email must be provided" : "必须提供合法的用户名",
-    "__language_name__" : "简体中文",
-    "Personal info" : "个人信息",
-    "Sync clients" : "客户端",
-    "Everything (fatal issues, errors, warnings, info, debug)" : "所有（灾难性问题，错误，警告，信息，调试）",
-    "Info, warnings, errors and fatal issues" : "信息，警告，错误和灾难性问题",
-    "Warnings, errors and fatal issues" : "警告，错误和灾难性问题",
-    "Errors and fatal issues" : "错误和灾难性问题",
-    "Fatal issues only" : "仅灾难性问题",
-    "None" : "无",
-    "Login" : "登录",
-    "Plain" : "Plain",
-    "NT LAN Manager" : "NT LAN 管理器",
-    "SSL" : "SSL",
-    "TLS" : "TLS",
-    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP 似乎没有设置好查询的系统环境变量。 用 getenv(\\\"PATH\\\") 测试只返回一个空值。",
-    "Please check the <a target=\"_blank\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "请检查PHP配置说明和服务器的 PHP 配置的 <a target=\"_blank\" href=\"%s\">安装文档 ↗</a>，使用 PHP-FPM 时尤其如此。",
-    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "只读配置已启用。这样可防止通过 WEB 接口设置一些配置。此外，每次更新后该文件需要手动设置为可写。",
-    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP 被设置为移除行内 <doc> 块，这将导致数个核心应用无法访问。",
-    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "这可能是由缓存/加速器造成的，例如 Zend OPcache 或 eAccelerator。",
-    "Your server is running on Microsoft Windows. We highly recommend Linux for optimal user experience." : "你的服务器是运行于 Microsoft Windows 系统。我们强烈推荐使用 Linux 系统以获得最佳的用户体验。比如中文文件夹和文件名支持。",
-    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP模块'文件信息'丢失. 我们强烈建议启用此模块以便mime类型检测取得最佳结果.",
-    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" href=\"%s\">documentation ↗</a> for more information." : "事务文件锁定被禁用，这可能会导致竞争条件问题。在config.php 中启用“filelocking.enabled”可以避免这些问题。请参阅<a target=\"_blank\" href=\"%s\">文档↗</a>了解详情。",
-    "System locale can not be set to a one which supports UTF-8." : "系统语系无法设置为支持 UTF-8 的语系。",
-    "This means that there might be problems with certain characters in file names." : "这意味着一些文件名中的特定字符可能有问题。",
-    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "我们强烈建议安装在系统上所需的软件包支持以下区域设置之一： %s.",
-    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "如果你不是安装在网域根目录而且又使用系统定时计划任务，那么可以导致 URL 链接生成问题。为了避免这些问题，请在你的 Config.php 文件中设置 \\\"overwrite.cli.url\\\" 选项为 webroot 安装根目录 (建议: \\\"%s\\\")",
-    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "由于下面的错误，无法通过 CLI 执行定时计划任务:",
-    "Please double check the <a target=\"_blank\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "请点击检查 <a target=\\\"_blank\\\" href=\\\"%s\\\"> 安装向导 ↗</a>, 点击 <a href=\\\"#log-section\\\"> 日志 </a>查看详细错误和警告。",
-    "All checks passed." : "所有检查已通过。",
-    "Open documentation" : "打开文档",
-    "Allow apps to use the Share API" : "允许应用软件使用共享API",
-    "Allow users to share via link" : "允许用户通过链接分享文件",
-    "Enforce password protection" : "强制密码保护",
-    "Allow public uploads" : "允许公开上传",
-    "Allow users to send mail notification for shared files" : "允许用户发送共享文件的邮件通知",
-    "Set default expiration date" : "设置默认过期日期",
-    "Expire after " : "过期于",
-    "days" : "天",
-    "Enforce expiration date" : "强制过期日期",
-    "Allow resharing" : "允许再次共享",
-    "Restrict users to only share with users in their groups" : "限制仅与组内用户分享",
-    "Allow users to send mail notification for shared files to other users" : "允许用户发送共享文件的邮件通知给其他用户",
-    "Exclude groups from sharing" : "在分享中排除组",
-    "These groups will still be able to receive shares, but not to initiate them." : "这些组将仍可以获取分享，但无法向他人分享。",
-    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "允许在共享对话框中的自动补全用户名。如果被禁用，需要输入用户全名。",
+    "Use the following link to confirm your changes to the email address: {link}" : "使用以下链接确认您对电子邮件地址的更改： {link}",
+    "Email address changed to {mailAddress} successfully." : "电子邮件地址已成功更改为 {mailAddress} 。",
+    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "亲，<br><br>现在我们为你开通了 %s 私有云帐户。<br><br>你的用户名： %s<br>访问网址： <a href=\\\"%s\\\">%s</a><br><br>",
+    "Cheers!" : "干杯！",
+    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "亲，\\n\\n 现在我们为你开通了 %s 私有去帐户。\\n\\n 你的用户名： %s\\n 访问网址： %s\\n 你的初始密码需要咨询系统管理员。或者你也可以在登录页面输入任意密码登录，\\n登录窗口将出现忘记密码链接，点击通过注册邮箱重设初始密码。\\n\\n",
+    "User documentation" : "用户文档",
+    "Administrator documentation" : "管理员文档",
+    "Online documentation" : "在线文档",
+    "Forum" : "论坛",
+    "Issue tracker" : "问题跟踪",
+    "Commercial support" : "商业支持",
+    "Apps Management" : "应用管理",
+    "Developer documentation" : "开发者文档",
+    "by %s" : "被 %s",
+    "%s-licensed" : "%s-许可协议",
+    "Documentation:" : "文档：",
+    "Admin documentation" : "管理员文档",
+    "Visit website" : "访问网站",
+    "Report a bug" : "报告  ",
+    "Show description …" : "显示描述...",
+    "Hide description …" : "隐藏描述...",
+    "This app has no minimum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "这个程序没有指定最低的ownCloud版本。这是在ownCloud11之后版本的错误。",
+    "This app has no maximum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "这个程序没有指定最高的ownCloud版本。这是在ownCloud11之后版本的错误。",
+    "This app cannot be installed because the following dependencies are not fulfilled:" : "此应用程序无法安装，因为以下依赖性不满足：",
+    "Enable only for specific groups" : "仅对特定的组开放",
+    "Uninstall App" : "卸载应用",
+    "Show enabled apps" : "显示启用的应用",
+    "Show disabled apps" : "显示禁用的应用",
+    "Cron" : "计划任务",
     "Last cron job execution: %s." : "上次定时任务执行于： %s.",
     "Last cron job execution: %s. Something seems wrong." : "上次定时任务执行于: %s. 似乎有些问题。",
     "Cron was not executed yet!" : "定时任务还未被执行！",
+    "Open documentation" : "打开文档",
     "Execute one task with each page loaded" : "每个页面加载后执行一个任务",
     "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php 已注册于一个 webcron 服务来通过 http 每 15 分钟执行 cron.php。",
     "Use system's cron service to call the cron.php file every 15 minutes." : "使用系统 CRON 服务每 15 分钟执行一次 cron.php 文件。",
+    "SSL Root Certificates" : "SSL 根证书",
+    "Common Name" : "通用名称",
+    "Valid until" : "有效期至",
+    "Issued By" : "授权由",
+    "Valid until %s" : "有效期至 %s",
+    "Import root certificate" : "导入根证书",
+    "Server-side encryption" : "服务器端加密",
     "Enable server-side encryption" : "启用服务器端加密",
     "Please read carefully before activating server-side encryption: " : "在激活服务器端加密之前，请仔细阅读：",
     "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "一旦加密被启用，之后上传到服务器的所有文件都将服务器上加密。只有当启用状态的加密模块支持解密并且所有的先决条件(例如，设定恢复键)得到满足时才能解除加密。",
@@ -168,6 +178,40 @@ OC.L10N.register(
     "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "你需要升级你的加密密钥 (旧版 ownCloud <= 8.0) 。 请在应用中启用 \\\"Default encryption module\\\" 并运行 'occ encryption:migrate'",
     "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "您需要将加密密钥从旧版(ownCloud<=8.0)迁移到新版。",
     "Start migration" : "开始迁移",
+    "Sharing" : "共享",
+    "Allow apps to use the Share API" : "允许应用软件使用共享API",
+    "Allow users to share via link" : "允许用户通过链接分享文件",
+    "Allow public uploads" : "允许公开上传",
+    "Enforce password protection" : "强制密码保护",
+    "Set default expiration date" : "设置默认过期日期",
+    "Allow users to send mail notification for shared files" : "允许用户发送共享文件的邮件通知",
+    "Allow users to share file via social media" : "允许用户通过社交媒体分享文件",
+    "Expire after " : "过期于",
+    "days" : "天",
+    "Enforce expiration date" : "强制过期日期",
+    "Allow resharing" : "允许再次共享",
+    "Allow sharing with groups" : "允许群组共享",
+    "Restrict users to only share with users in their groups" : "限制仅与组内用户分享",
+    "Allow users to send mail notification for shared files to other users" : "允许用户发送共享文件的邮件通知给其他用户",
+    "Exclude groups from sharing" : "在分享中排除组",
+    "These groups will still be able to receive shares, but not to initiate them." : "这些组将仍可以获取分享，但无法向他人分享。",
+    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "允许在共享对话框中的自动补全用户名。如果被禁用，需要输入用户全名。",
+    "Everything (fatal issues, errors, warnings, info, debug)" : "所有（灾难性问题，错误，警告，信息，调试）",
+    "Info, warnings, errors and fatal issues" : "信息，警告，错误和灾难性问题",
+    "Warnings, errors and fatal issues" : "警告，错误和灾难性问题",
+    "Errors and fatal issues" : "错误和灾难性问题",
+    "Fatal issues only" : "仅灾难性问题",
+    "Log" : "日志",
+    "What to log" : "记录日志",
+    "Download logfile (%s)" : "下载日志文件 (%s)",
+    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "日志文件超过 100 MB。下载可能需要一些时间！",
+    "None" : "无",
+    "Login" : "登录",
+    "Plain" : "Plain",
+    "NT LAN Manager" : "NT LAN 管理器",
+    "SSL/TLS" : "SSL/TLS",
+    "STARTTLS" : "STARTTLS",
+    "Email server" : "电子邮件服务器",
     "This is used for sending out notifications." : "这被用于发送通知。",
     "Send mode" : "发送模式",
     "Encryption" : "加密",
@@ -183,49 +227,42 @@ OC.L10N.register(
     "Store credentials" : "存储凭据",
     "Test email settings" : "测试电子邮件设置",
     "Send email" : "发送邮件",
-    "Download logfile" : "下载日志文件",
-    "More" : "更多",
-    "Less" : "更少",
-    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "日志文件超过 100 MB。下载可能需要一些时间！",
-    "What to log" : "记录日志",
+    "Security & setup warnings" : "安全及设置警告",
+    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP 似乎没有设置好查询的系统环境变量。 用 getenv(\\\"PATH\\\") 测试只返回一个空值。",
+    "Please check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "请检查 PHP 配置说明和服务器的 PHP 配置 <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">安装文档 ↗</a>，使用 PHP-FPM 时尤其注意。",
+    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "只读配置已启用。这样可防止通过 WEB 接口设置一些配置。此外，每次更新后该文件需要手动设置为可写。",
+    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP 被设置为移除行内 <doc> 块，这将导致数个核心应用无法访问。",
+    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "这可能是由缓存/加速器造成的，例如 Zend OPcache 或 eAccelerator。",
+    "Your database does not run with \"READ COMMITED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "您的数据库没有采用“READ COMMITTED”事务隔离级别运行。当多个操作并行执行时可能导致问题。",
+    "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version." : "%1$s 下版本 %2$s 已安装。基于稳定和性能的原因，我们强烈建议更新至 %1$s 版本。",
+    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP模块'文件信息'丢失. 我们强烈建议启用此模块以便mime类型检测取得最佳结果.",
+    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "事务文件锁定被禁用，这可能会导致竞争条件问题。在config.php 中启用“filelocking.enabled”可以避免这些问题。请参阅 <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">文档↗</a>了解详情。",
+    "Transactional file locking should be configured to use memory-based locking, not the default slow database-based locking. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "事务文件锁定应配置为使用基于内存的锁定，而不是默认的基于慢速数据库的锁定。有关详细信息，请参阅 <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">文档 ↗</a>。",
+    "System locale can not be set to a one which supports UTF-8." : "系统语系无法设置为支持 UTF-8 的语系。",
+    "This means that there might be problems with certain characters in file names." : "这意味着一些文件名中的特定字符可能有问题。",
+    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "我们强烈建议安装在系统上所需的软件包支持以下区域设置之一： %s.",
+    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "如果你不是安装在网域根目录而且又使用系统定时计划任务，那么可以导致 URL 链接生成问题。为了避免这些问题，请在你的 Config.php 文件中设置 \\\"overwrite.cli.url\\\" 选项为 webroot 安装根目录 (建议: \\\"%s\\\")",
     "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLite 被用作数据库。对于较大数据量的安装和使用，我们建议您切换到不同的数据库后端。",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "特别当使用桌面客户端来同步文件时，不鼓励使用 SQLite 。",
-    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" href=\"%s\">documentation ↗</a>." : "要迁移到另一个数据库请使用命令行工具: 'occ db:convert-type', 或者查看 <a target=\\\"_blank\\\" href=\\\"%s\\\"> 相关文档 ↗</a>.",
+    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a>." : "要迁移到另一个数据库请使用命令行工具: 'occ db:convert-type', 或者查看 <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\"> 相关文档 ↗</a>.",
+    "We recommend to enable system cron as any other cron method has possible performance and reliability implications." : "我们建议启用系统 cron，任何其他 cron 方法可能对性能和可靠性有影响。",
+    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "由于下面的错误，无法通过 CLI 执行定时计划任务:",
+    "Please double check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "请点击检查<a target=\"_blank\" rel=\"noreferrer\" href=\"%s\"> 安装向导 ↗</a>，点击 <a href=\\\"#log-section\\\"> 日志 </a>查看详细错误和警告。",
+    "All checks passed." : "所有检查已通过。",
+    "System Status" : "系统状态",
+    "Tips & tricks" : "技巧提示",
     "How to do backups" : "如何做备份",
     "Advanced monitoring" : "高级监控",
     "Performance tuning" : "性能优化",
     "Improving the config.php" : "正在优化 config.php",
     "Theming" : "主题",
     "Hardening and security guidance" : "强化和安全指南",
-    "Version" : "版本",
-    "Developer documentation" : "开发者文档",
-    "Experimental applications ahead" : "未来的实验应用",
-    "Experimental apps are not checked for security issues, new or known to be unstable and under heavy development. Installing them can cause data loss or security breaches." : "实验应用程序没有在安全性的问题上作过多检查，新的或已知的不稳定 BUG 都在开发中。安装它们可能会导致数据丢失或安全漏洞。",
-    "Documentation:" : "文档：",
-    "User documentation" : "用户文档",
-    "Admin documentation" : "管理员文档",
-    "Show description …" : "显示描述...",
-    "Hide description …" : "隐藏描述...",
-    "This app has no minimum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "这个程序没有指定最低的ownCloud版本。这是在ownCloud11之后版本的错误。",
-    "This app has no maximum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "这个程序没有指定最高的ownCloud版本。这是在ownCloud11之后版本的错误。",
-    "This app cannot be installed because the following dependencies are not fulfilled:" : "此应用程序无法安装，因为以下依赖性不满足：",
-    "Enable only for specific groups" : "仅对特定的组开放",
-    "Uninstall App" : "卸载应用",
-    "Enable experimental apps" : "启用实验性应用程序",
-    "SSL Root Certificates" : "SSL 根证书",
-    "Common Name" : "通用名称",
-    "Valid until" : "有效期至",
-    "Issued By" : "授权由",
-    "Valid until %s" : "有效期至 %s",
-    "Import root certificate" : "导入根证书",
-    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "亲，<br><br>现在我们为你开通了 %s 私有云帐户。<br><br>你的用户名： %s<br>访问网址： <a href=\\\"%s\\\">%s</a><br><br>",
-    "Cheers!" : "干杯！",
-    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "亲，\\n\\n 现在我们为你开通了 %s 私有去帐户。\\n\\n 你的用户名： %s\\n 访问网址： %s\\n 你的初始密码需要咨询系统管理员。或者你也可以在登录页面输入任意密码登录，\\n登录窗口将出现忘记密码链接，点击通过注册邮箱重设初始密码。\\n\\n",
-    "Administrator documentation" : "管理员文档",
-    "Online documentation" : "在线文档",
-    "Forum" : "论坛",
-    "Issue tracker" : "问题跟踪",
-    "Commercial support" : "商业支持",
+    "Get the apps to sync your files" : "安装应用进行文件同步",
+    "Desktop client" : "桌面客户端",
+    "Android app" : "Android 应用",
+    "iOS app" : "iOS 应用",
+    "If you want to support the project\n\t\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\t\tor\n\t\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "如果您想支持此项目\n\t\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">加入开发</a>\n\t\t\tor\n\t\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">分享</a>!",
+    "Show First Run Wizard again" : "再次显示首次运行向导",
     "Profile picture" : "联系人图片",
     "Upload new" : "上传新的",
     "Select from Files" : "选择文件",
@@ -238,6 +275,8 @@ OC.L10N.register(
     "No display name set" : "不显示名称设置",
     "Email" : "电子邮件",
     "Your email address" : "您的电子邮件",
+    "Change email" : "修改电子邮件",
+    "Set email" : "设置电子邮件",
     "For password recovery and notifications" : "用户恢复密码通知",
     "No email address set" : "尚未设置 Email 地址",
     "You are member of the following groups:" : "您是以下组的成员：",
@@ -248,19 +287,34 @@ OC.L10N.register(
     "Change password" : "修改密码",
     "Language" : "语言",
     "Help translate" : "帮助翻译",
-    "Get the apps to sync your files" : "安装应用进行文件同步",
-    "Desktop client" : "桌面客户端",
-    "Android app" : "Android 应用",
-    "iOS app" : "iOS 应用",
-    "If you want to support the project\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\tor\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "想支持ownCloud项目？请\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">参加开发</a>\n\t\t或者\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">帮助推广</a>吧！",
-    "Show First Run Wizard again" : "再次显示首次运行向导",
+    "Unlimited" : "无限",
+    "You are using %s of %s" : "您正在使用 %s of %s",
+    "You are using %s of %s (%s %%)" : "您正在在使用 %s of %s (%s %%)",
     "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "由 {communityopen}ownCloud 社区{linkclose}开发，{githubopen}源代码{linkclose}的发布需遵守 {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr> 许可协议{linkclose}。",
+    "Sessions" : "会话",
+    "These are the web, desktop and mobile clients currently logged in to your ownCloud." : "以下是当前登录到你的云服务器的 Web，桌面和移动端会话列表。",
+    "Browser" : "浏览器",
+    "Most recent activity" : "最近的活动",
+    "App passwords" : "应用密码",
+    "You've linked these apps." : "您已经链接这些应用。",
+    "Name" : "名称",
+    "An app password is a passcode that gives an app or device permissions to access your %s account." : "应用密码是一种授权码，即授权应用或设备访问您的 %s 帐户。",
+    "App name" : "应用名称",
+    "Create new app password" : "创建新的应用密码",
+    "Use the credentials below to configure your app or device." : "使用以下凭据来配置你的应用或设备。",
+    "Username" : "用户名",
+    "Done" : "完成",
+    "Version" : "版本",
+    "Personal" : "个人",
+    "Admin" : "管理",
+    "Error" : "错误",
+    "No panels for this section." : "本节没有面板。",
+    "Show enabled/disabled option" : "显示 启用/禁用 选项",
     "Show storage location" : "显示存储位置",
     "Show last log in" : "显示最后登录",
     "Show user backend" : "显示用户后端",
     "Send email to new user" : "发送电子邮件给新用户",
     "Show email address" : "显示邮件地址",
-    "Username" : "用户名",
     "E-Mail" : "E-Mail",
     "Create" : "创建",
     "Admin Recovery Password" : "管理恢复密码",
@@ -271,7 +325,6 @@ OC.L10N.register(
     "Admins" : "管理员",
     "Default Quota" : "默认配额",
     "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "请输入存储限额 (ex: \"512 MB\" or \"12 GB\")",
-    "Unlimited" : "无限",
     "Other" : "其它",
     "Full Name" : "全名",
     "Group Admin for" : "设为以下组管理员",
