@@ -2,13 +2,18 @@
 /**
  * @author Andreas Fischer <bantu@owncloud.com>
  * @author Christopher Schäpers <kondou@ts.unde.re>
- * @author Frank Karlitschek <frank@owncloud.org>
+ * @author Frank Karlitschek <frank@karlitschek.de>
+ * @author Joas Schilling <coding@schilljs.com>
  * @author Jörn Friedrich Dreyer <jfd@butonic.de>
- * @author Lukas Reschke <lukas@owncloud.com>
+ * @author Kristof Provost <github@sigsegv.be>
+ * @author Lukas Reschke <lukas@statuscode.ch>
+ * @author martin.mattel@diemattels.at <martin.mattel@diemattels.at>
  * @author Masaki Kawabata Neto <masaki.kawabata@gmail.com>
  * @author Morris Jobke <hey@morrisjobke.de>
+ * @author Philipp Schaffrath <github@philippschaffrath.de>
+ * @author Thomas Müller <thomas.mueller@tmit.eu>
  *
- * @copyright Copyright (c) 2016, ownCloud, Inc.
+ * @copyright Copyright (c) 2017, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -27,18 +32,10 @@
 
 try {
 
-	require_once 'lib/base.php';
+	require_once __DIR__ . '/lib/base.php';
 
-	$systemConfig = \OC::$server->getSystemConfig();
+	$values = \OCP\Util::getStatusInfo();
 
-	$installed = (bool) $systemConfig->getValue('installed', false);
-	$maintenance = (bool) $systemConfig->getValue('maintenance', false);
-	$values=array(
-		'installed'=>$installed,
-		'maintenance' => $maintenance,
-		'version'=>implode('.', \OCP\Util::getVersion()),
-		'versionstring'=>OC_Util::getVersionString(),
-		'edition'=>OC_Util::getEditionString());
 	if (OC::$CLI) {
 		print_r($values);
 	} else {
